from nicegui import ui
from biblemateweb.css.original import ORIGINAL_CSS
from biblemateweb.fx.bible import *
from biblemateweb.fx.original import *
from biblemateweb.js.sync_scrolling import *
import re


def original_linguistic(b=1, c=1, v=1, area=1, tab1=None, tab2=None, **_):

    # listen for custom event "luW"
    ui.on('luW', luW)
    ui.on('luV', luV)
    ui.on('lex', lex)
    ui.on('bdbid', bdbid)
    ui.on('etcbcmorph', etcbcmorph)
    ui.on('rmac', rmac)
    ui.on('searchWord', searchWord)
    ui.on('searchLexicalEntry', searchLexicalEntry)

    # Your provided HTML snippet [for TESTING only; only real data when deloy]
    hebrew_content = """<verse><vid id="v19.117.1" onclick="luV(1)">1</vid> <cl><div class="bhc"><div id="c70320" class="cdesc"><ref onclick="cl('70320')">°</ref> | <ref onclick="cl('70320')"><clid>c70320</clid></ref> | <ckind>Verbal clauses,</ckind> <ctyp>Zero-imperative-null clause</ctyp></div> <div class="bhp"><div id="p198017" class="pdesc"><ptyp>Verbal phrase</ptyp><br> <pfunction>Predicate</pfunction></div><div class="bhw"><heb id="wh331049" class="ch70320 GE70639 H1984" onclick="luW(1,'331049','70320','70639','verb.piel.impv.p2.m.pl','H1984')" onmouseover="hl1('h331049','h70320','E70639')" onmouseout="hl0('h331049','h70320','E70639')" ondblclick="searchWord(1,331049)">הַֽלְל֣וּ</heb><br><hbint>[you]+ praise</hbint></div><heb> </heb></div> <div class="bhp"><div id="p198018" class="pdesc"><ptyp><det>Prepositional phrase</det></ptyp><br> <pfunction>Object</pfunction></div><div class="bhw"><heb id="wh331050" class="ch70320 GE70005 H853" onclick="luW(1,'331050','70320','70005','prep','H853')" onmouseover="hl1('h331050','h70320','E70005')" onmouseout="hl0('h331050','h70320','E70005')" ondblclick="searchWord(1,331050)">אֶת</heb><heb>־</heb><br><hbint>[object marker]</hbint></div><div class="bhw"><heb id="wh331051" class="ch70320 GE70113 H3068" onclick="luW(1,'331051','70320','70113','nmpr.m.sg.a','H3068')" onmouseover="hl1('h331051','h70320','E70113')" onmouseout="hl0('h331051','h70320','E70113')" ondblclick="searchWord(1,331051)">יְ֭הוָה</heb><br><hbint>YHWH</hbint></div><heb> </heb></div></div></cl><cl><div class="bhc"><div id="c70321.c70320" class="cdesc"><ref onclick="cl('70321')">°°°</ref> | <ref onclick="cl('70321')"><clid>c70321</clid></ref> <connector>@</connector><ref onclick="cl('70320')"><mclid>c70320</mclid></ref> | <ckind>Clauses without predication,</ckind> <ctyp>Vocative clause</ctyp></div> <div class="bhp"><div id="p198019" class="pdesc"><ptyp><undet>Nominal phrase</undet></ptyp><br> <pfunction>Vocative</pfunction></div><div class="bhw"><heb id="wh331052" class="ch70321 GE70078 H3605" onclick="luW(1,'331052','70321','70078','subs.m.sg.c','H3605')" onmouseover="hl1('h331052','h70321','E70078')" onmouseout="hl0('h331052','h70321','E70078')" ondblclick="searchWord(1,331052)">כָּל</heb><heb>־</heb><br><hbint>whole</hbint></div><div class="bhw"><heb id="wh331053" class="ch70321 GE70500 H1471" onclick="luW(1,'331053','70321','70500','subs.m.pl.a','H1471')" onmouseover="hl1('h331053','h70321','E70500')" onmouseout="hl0('h331053','h70321','E70500')" ondblclick="searchWord(1,331053)">גֹּויִ֑ם</heb><br><hbint>people</hbint></div><heb> </heb></div></div></cl><cl><div class="bhc"><div id="c70322.c70320" class="cdesc"><ref onclick="cl('70322')">°°</ref> | <ref onclick="cl('70322')"><clid>c70322</clid></ref> <connector>@</connector><ref onclick="cl('70320')"><mclid>c70320</mclid></ref> | <ckind>Verbal clauses,</ckind> <ctyp>Zero-imperative-null clause</ctyp></div> <div class="bhp"><div id="p198020" class="pdesc"><ptyp>Verbal phrase</ptyp><br> <pfunction>Predicate with object suffix</pfunction></div><div class="bhw"><heb id="wh331054" class="ch70322 GE76864 H7623" onclick="luW(1,'331054','70322','76864','verb.piel.impv.p2.m.pl.prs.p3.m.sg','H7623')" onmouseover="hl1('h331054','h70322','E76864')" onmouseout="hl0('h331054','h70322','E76864')" ondblclick="searchWord(1,331054)">שַׁ֝בְּח֗וּהוּ</heb><br><hbint>[you]+ praise +[him]</hbint></div><heb> </heb></div></div></cl><cl><div class="bhc"><div id="c70323.c70322" class="cdesc"><ref onclick="cl('70323')">°°°°</ref> | <ref onclick="cl('70323')"><clid>c70323</clid></ref> <connector>@</connector><ref onclick="cl('70322')"><mclid>c70322</mclid></ref> | <ckind>Clauses without predication,</ckind> <ctyp>Vocative clause</ctyp></div> <div class="bhp"><div id="p198021" class="pdesc"><ptyp><det>Nominal phrase</det></ptyp><br> <pfunction>Vocative</pfunction></div><div class="bhw"><heb id="wh331055" class="ch70323 GE70078 H3605" onclick="luW(1,'331055','70323','70078','subs.m.sg.c','H3605')" onmouseover="hl1('h331055','h70323','E70078')" onmouseout="hl0('h331055','h70323','E70078')" ondblclick="searchWord(1,331055)">כָּל</heb><heb>־</heb><br><hbint>whole</hbint></div><div class="bhw"><heb id="wh331056" class="ch70323 GE70006 H9009" onclick="luW(1,'331056','70323','70006','art','H9009')" onmouseover="hl1('h331056','h70323','E70006')" onmouseout="hl0('h331056','h70323','E70006')" ondblclick="searchWord(1,331056)">הָ</heb><heb></heb><br><hbint>the</hbint></div><div class="bhw"><heb id="wh331057" class="ch70323 GE71088 H523" onclick="luW(1,'331057','70323','71088','subs.f.pl.a','H523')" onmouseover="hl1('h331057','h70323','E71088')" onmouseout="hl0('h331057','h70323','E71088')" ondblclick="searchWord(1,331057)">אֻמִּֽים</heb><heb>׃ </heb><br><hbint>clan</hbint></div></div></div></cl></verse> <verse><vid id="v19.117.2" onclick="luV(2)">2</vid> <cl><div class="bhc"><div id="c70324.c70322" class="cdesc"><ref onclick="cl('70324')">°°°</ref> | <ref onclick="cl('70324')"><clid>c70324</clid></ref> <connector>@</connector><ref onclick="cl('70322')"><mclid>c70322</mclid></ref> | <ckind>Verbal clauses,</ckind> <ctyp>x-qatal-X clause</ctyp></div> <div class="bhp"><div id="p198022" class="pdesc"><ptyp>Conjunctive phrase</ptyp><br> <pfunction>Conjunction</pfunction></div><div class="bhw"><heb id="wh331058" class="ch70324 GE70023 H3588" onclick="luW(2,'331058','70324','70023','conj','H3588')" onmouseover="hl1('h331058','h70324','E70023')" onmouseout="hl0('h331058','h70324','E70023')" ondblclick="searchWord(1,331058)">כִּ֥י</heb><br><hbint>that</hbint></div><heb> </heb></div> <div class="bhp"><div id="p198023" class="pdesc"><ptyp>Verbal phrase</ptyp><br> <pfunction>Predicate</pfunction></div><div class="bhw"><heb id="wh331059" class="ch70324 GE70414 H1396" onclick="luW(2,'331059','70324','70414','verb.qal.perf.p3.m.sg','H1396')" onmouseover="hl1('h331059','h70324','E70414')" onmouseout="hl0('h331059','h70324','E70414')" ondblclick="searchWord(1,331059)">גָ֘בַ֤ר</heb><br><hbint>[he]+ be superior</hbint></div><heb> </heb></div> <div class="bhp"><div id="p198024" class="pdesc"><ptyp><det>Prepositional phrase</det></ptyp><br> <pfunction>Complement</pfunction></div><div class="bhw"><heb id="wh331060" class="ch70324 GE70014 H5921" onclick="luW(2,'331060','70324','70014','prep.prs.p1.u.pl','H5921')" onmouseover="hl1('h331060','h70324','E70014')" onmouseout="hl0('h331060','h70324','E70014')" ondblclick="searchWord(1,331060)">עָלֵ֨ינוּ</heb><heb>׀ </heb><br><hbint>upon +[us]</hbint></div></div> <div class="bhp"><div id="p198025" class="pdesc"><ptyp><det>Nominal phrase</det></ptyp><br> <pfunction>Subject</pfunction></div><div class="bhw"><heb id="wh331061" class="ch70324 GE70897 H2617" onclick="luW(2,'331061','70324','70897','subs.m.sg.a.prs.p3.m.sg','H2617')" onmouseover="hl1('h331061','h70324','E70897')" onmouseout="hl0('h331061','h70324','E70897')" ondblclick="searchWord(1,331061)">חַסְדֹּ֗ו</heb><br><hbint>+[his] loyalty</hbint></div><heb> </heb></div></div></cl><cl><div class="bhc"><div id="c70325.c70324" class="cdesc"><ref onclick="cl('70325')">°°°°</ref> | <ref onclick="cl('70325')"><clid>c70325</clid></ref> <connector>@</connector><ref onclick="cl('70324')"><mclid>c70324</mclid></ref> | <ckind>Nominal clauses,</ckind> <ctyp>Nominal clause,</ctyp> <crela>Coordinated clause</crela></div> <div class="bhp"><div id="p198026" class="pdesc"><ptyp>Conjunctive phrase</ptyp><br> <pfunction>Conjunction</pfunction></div><div class="bhw"><heb id="wh331062" class="ch70325 GE70008 H9000" onclick="luW(2,'331062','70325','70008','conj','H9000')" onmouseover="hl1('h331062','h70325','E70008')" onmouseout="hl0('h331062','h70325','E70008')" ondblclick="searchWord(1,331062)">וֶֽ</heb><heb></heb><br><hbint>and</hbint></div></div> <div class="bhp"><div id="p198027" class="pdesc"><ptyp><det>Nominal phrase</det></ptyp><br> <pfunction>Subject</pfunction></div><div class="bhw"><heb id="wh331063" class="ch70325 GE71035 H571" onclick="luW(2,'331063','70325','71035','subs.f.sg.c','H571')" onmouseover="hl1('h331063','h70325','E71035')" onmouseout="hl0('h331063','h70325','E71035')" ondblclick="searchWord(1,331063)">אֱמֶת</heb><heb>־</heb><br><hbint>trustworthiness</hbint></div><div class="bhw"><heb id="wh331064" class="ch70325 GE70113 H3068" onclick="luW(2,'331064','70325','70113','nmpr.m.sg.a','H3068')" onmouseover="hl1('h331064','h70325','E70113')" onmouseout="hl0('h331064','h70325','E70113')" ondblclick="searchWord(1,331064)">יְהוָ֥ה</heb><br><hbint>YHWH</hbint></div><heb> </heb></div> <div class="bhp"><div id="p198028" class="pdesc"><ptyp><undet>Prepositional phrase</undet></ptyp><br> <pfunction>Predicate complement</pfunction></div><div class="bhw"><heb id="wh331065" class="ch70325 GE70028 H9005" onclick="luW(2,'331065','70325','70028','prep','H9005')" onmouseover="hl1('h331065','h70325','E70028')" onmouseout="hl0('h331065','h70325','E70028')" ondblclick="searchWord(1,331065)">לְ</heb><heb></heb><br><hbint>to</hbint></div><div class="bhw"><heb id="wh331066" class="ch70325 GE70253 H5769" onclick="luW(2,'331066','70325','70253','subs.m.sg.a','H5769')" onmouseover="hl1('h331066','h70325','E70253')" onmouseout="hl0('h331066','h70325','E70253')" ondblclick="searchWord(1,331066)">עֹולָ֗ם</heb><br><hbint>eternity</hbint></div><heb> </heb></div></div></cl><cl><div class="bhc"><div id="c70326.c70320" class="cdesc"><ref onclick="cl('70326')">°</ref> | <ref onclick="cl('70326')"><clid>c70326</clid></ref> <connector>@</connector><ref onclick="cl('70320')"><mclid>c70320</mclid></ref> | <ckind>Verbal clauses,</ckind> <ctyp>Zero-imperative-null clause</ctyp></div> <div class="bhp"><div id="p198029" class="pdesc"><ptyp>Verbal phrase</ptyp><br> <pfunction>Predicate</pfunction></div><div class="bhw"><heb id="wh331067" class="ch70326 GE70639 H1984" onclick="luW(2,'331067','70326','70639','verb.piel.impv.p2.m.pl','H1984')" onmouseover="hl1('h331067','h70326','E70639')" onmouseout="hl0('h331067','h70326','E70639')" ondblclick="searchWord(1,331067)">הַֽלְלוּ</heb><heb>־</heb><br><hbint>[you]+ praise</hbint></div></div> <div class="bhp"><div id="p198030" class="pdesc"><ptyp><det>Proper-noun phrase</det></ptyp><br> <pfunction>Object</pfunction></div><div class="bhw"><heb id="wh331068" class="ch70326 GE72038 H3050" onclick="luW(2,'331068','70326','72038','nmpr.m.sg.a','H3050')" onmouseover="hl1('h331068','h70326','E72038')" onmouseout="hl0('h331068','h70326','E72038')" ondblclick="searchWord(1,331068)">יָֽהּ</heb><heb>׃ </heb><br><hbint>the Lord</hbint></div></div></div></cl></verse>"""

    greek_content = """<verse><vid id="v63.1.1" onclick="luV(1)">1</vid> <cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:1.w1-w8</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:1.w1-w2</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127242" cl='c24856' sn='G3588' morph='T-NSM' class="G3588" onclick="luW(1,'127242','24856','3588','T-NSM')" onmouseover="hl1('127242','24856','3588')" onmouseout="hl0('127242','24856','3588')" ondblclick="searchWord(2,127242)">Ὁ</grk><br><gloss>The</gloss></div></w> <w><div class='w'><wordid>w2</wordid><br><funcinfo>head</funcinfo><br><grk id="w127243" cl='c24856' sn='G4245' morph='A-NSM' class="G4245" onclick="luW(1,'127243','24856','4245','A-NSM')" onmouseover="hl1('127243','24856','4245')" onmouseout="hl0('127243','24856','4245')" ondblclick="searchWord(2,127243)">πρεσβύτερος</grk><br><gloss>elder,</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w3-w8</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w3-w4</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w3</wordid><br><funcinfo>definer</funcinfo><br><grk id="w127244" cl='c24856' sn='G1588' morph='A-DSF' class="G1588" onclick="luW(1,'127244','24856','1588','A-DSF')" onmouseover="hl1('127244','24856','1588')" onmouseout="hl0('127244','24856','1588')" ondblclick="searchWord(2,127244)">Ἐκλεκτῇ</grk><br><gloss>To [the] elect</gloss></div></w> <w><div class='w'><wordid>w4</wordid><br><funcinfo>head</funcinfo><br><grk id="w127245" cl='c24856' sn='G2959' morph='N-DSF' class="G2959" onclick="luW(1,'127245','24856','2959','N-DSF')" onmouseover="hl1('127245','24856','2959')" onmouseout="hl0('127245','24856','2959')" ondblclick="searchWord(2,127245)">κυρίᾳ</grk><br><gloss>lady</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w5-w8</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w5</wordid><br><funcinfo>connector</funcinfo><br><grk id="w127246" cl='c24856' sn='G2532' morph='CONJ' class="G2532" onclick="luW(1,'127246','24856','2532','CONJ')" onmouseover="hl1('127246','24856','2532')" onmouseout="hl0('127246','24856','2532')" ondblclick="searchWord(2,127246)">καὶ</grk><br><gloss>and</gloss></div></w> <w><div class='w'><wordid>w6</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127247" cl='c24856' sn='G3588' morph='T-DPN' class="G3588" onclick="luW(1,'127247','24856','3588','T-DPN')" onmouseover="hl1('127247','24856','3588')" onmouseout="hl0('127247','24856','3588')" ondblclick="searchWord(2,127247)">τοῖς</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w7</wordid><br><funcinfo>head</funcinfo><br><grk id="w127248" cl='c24856' sn='G5043' morph='N-DPN' class="G5043" onclick="luW(1,'127248','24856','5043','N-DPN')" onmouseover="hl1('127248','24856','5043')" onmouseout="hl0('127248','24856','5043')" ondblclick="searchWord(2,127248)">τέκνοις</grk><br><gloss>children</gloss></div></w> <w><div class='w'><wordid>w8</wordid><br><funcinfo>qualifier</funcinfo><br><grk id="w127249" cl='c24856' sn='G846' morph='P-GSF' class="G846" onclick="luW(1,'127249','24856','846','P-GSF')" onmouseover="hl1('127249','24856','846')" onmouseout="hl0('127249','24856','846')" ondblclick="searchWord(2,127249)">αὐτῆς</grk><br><gloss>of her,</gloss></div></w></div></div></wg></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:1.w9-w13</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:1.w1-w8</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:1.w9</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w9</wordid><br><funcinfo>head</funcinfo><br><grk id="w127250" cl='c24857' sn='G3739' morph='R-APM' class="G3739" onclick="luW(1,'127250','24857','3739','R-APM')" onmouseover="hl1('127250','24857','3739')" onmouseout="hl0('127250','24857','3739')" ondblclick="searchWord(2,127250)">οὓς</grk><br><gloss>whom</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w10</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w10</wordid><br><funcinfo>head</funcinfo><br><grk id="w127251" cl='c24857' sn='G1473' morph='P-1NS' class="G1473" onclick="luW(1,'127251','24857','1473','P-1NS')" onmouseover="hl1('127251','24857','1473')" onmouseout="hl0('127251','24857','1473')" ondblclick="searchWord(2,127251)">ἐγὼ</grk><br><gloss>I</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w11</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w11</wordid><br><funcinfo>head</funcinfo><br><grk id="w127252" cl='c24857' sn='G25' morph='V-PAI-1S' class="G25" onclick="luW(1,'127252','24857','25','V-PAI-1S')" onmouseover="hl1('127252','24857','25')" onmouseout="hl0('127252','24857','25')" ondblclick="searchWord(2,127252)">ἀγαπῶ</grk><br><gloss>love</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w12-w13</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w12</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127253" cl='c24857' sn='G1722' morph='PREP' class="G1722" onclick="luW(1,'127253','24857','1722','PREP')" onmouseover="hl1('127253','24857','1722')" onmouseout="hl0('127253','24857','1722')" ondblclick="searchWord(2,127253)">ἐν</grk><br><gloss>in</gloss></div></w> <w><div class='w'><wordid>w13</wordid><br><funcinfo>head</funcinfo><br><grk id="w127254" cl='c24857' sn='G225' morph='N-DSF' class="G225" onclick="luW(1,'127254','24857','225','N-DSF')" onmouseover="hl1('127254','24857','225')" onmouseout="hl0('127254','24857','225')" ondblclick="searchWord(2,127254)">ἀληθείᾳ</grk><br><gloss>truth,</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:1.w14-w17</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:1.w9-w13</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:1.w14</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w14</wordid><br><funcinfo>head</funcinfo><br><grk id="w127255" cl='c24858' sn='G2532' morph='CONJ' class="G2532" onclick="luW(1,'127255','24858','2532','CONJ')" onmouseover="hl1('127255','24858','2532')" onmouseout="hl0('127255','24858','2532')" ondblclick="searchWord(2,127255)">καὶ</grk><br><gloss>and</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w15</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w15</wordid><br><funcinfo>head</funcinfo><br><grk id="w127256" cl='c24858' sn='G3756' morph='PRT-N' class="G3756" onclick="luW(1,'127256','24858','3756','PRT-N')" onmouseover="hl1('127256','24858','3756')" onmouseout="hl0('127256','24858','3756')" ondblclick="searchWord(2,127256)">οὐκ</grk><br><gloss>not</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w16</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w16</wordid><br><funcinfo>head</funcinfo><br><grk id="w127257" cl='c24858' sn='G1473' morph='P-1NS' class="G1473" onclick="luW(1,'127257','24858','1473','P-1NS')" onmouseover="hl1('127257','24858','1473')" onmouseout="hl0('127257','24858','1473')" ondblclick="searchWord(2,127257)">ἐγὼ</grk><br><gloss>I</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w17</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w17</wordid><br><funcinfo>head</funcinfo><br><grk id="w127258" cl='c24858' sn='G3441' morph='A-NSM' class="G3441" onclick="luW(1,'127258','24858','3441','A-NSM')" onmouseover="hl1('127258','24858','3441')" onmouseout="hl0('127258','24858','3441')" ondblclick="searchWord(2,127258)">μόνος</grk><br><gloss>only,</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:1.w18-2.w14</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:1.w14-w17</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:1.w18</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w18</wordid><br><funcinfo>head</funcinfo><br><grk id="w127259" cl='c24859' sn='G235' morph='CONJ' class="G235" onclick="luW(1,'127259','24859','235','CONJ')" onmouseover="hl1('127259','24859','235')" onmouseout="hl0('127259','24859','235')" ondblclick="searchWord(2,127259)">ἀλλὰ</grk><br><gloss>but</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w19</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w19</wordid><br><funcinfo>head</funcinfo><br><grk id="w127260" cl='c24859' sn='G2532' morph='CONJ' class="G2532" onclick="luW(1,'127260','24859','2532','CONJ')" onmouseover="hl1('127260','24859','2532')" onmouseout="hl0('127260','24859','2532')" ondblclick="searchWord(2,127260)">καὶ</grk><br><gloss>also</gloss></div></w></div></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>subject</funcinfo> <b><clinfo>1:1.w20-w24</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:1.w20-w22</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w20</wordid><br><funcinfo>definer</funcinfo><br><grk id="w127261" cl='c24859' sn='G3956' morph='A-NPM' class="G3956" onclick="luW(1,'127261','24859','3956','A-NPM')" onmouseover="hl1('127261','24859','3956')" onmouseout="hl0('127261','24859','3956')" ondblclick="searchWord(2,127261)">πάντες</grk><br><gloss>all</gloss></div></w> <w><div class='w'><wordid>w21</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127262" cl='c24859' sn='G3588' morph='T-NPM' class="G3588" onclick="luW(1,'127262','24859','3588','T-NPM')" onmouseover="hl1('127262','24859','3588')" onmouseout="hl0('127262','24859','3588')" ondblclick="searchWord(2,127262)">οἱ</grk><br><gloss>those</gloss></div></w> <w><div class='w'><wordid>w22</wordid><br><funcinfo>head</funcinfo><br><grk id="w127263" cl='c24859' sn='G1097' morph='V-RAP-NPM' class="G1097" onclick="luW(1,'127263','24859','1097','V-RAP-NPM')" onmouseover="hl1('127263','24859','1097')" onmouseout="hl0('127263','24859','1097')" ondblclick="searchWord(2,127263)">ἐγνωκότες</grk><br><gloss>having known</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:1.w23-w24</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w23</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127264" cl='c24859' sn='G3588' morph='T-ASF' class="G3588" onclick="luW(1,'127264','24859','3588','T-ASF')" onmouseover="hl1('127264','24859','3588')" onmouseout="hl0('127264','24859','3588')" ondblclick="searchWord(2,127264)">τὴν</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w24</wordid><br><funcinfo>head</funcinfo><br><grk id="w127265" cl='c24859' sn='G225' morph='N-ASF' class="G225" onclick="luW(1,'127265','24859','225','N-ASF')" onmouseover="hl1('127265','24859','225')" onmouseout="hl0('127265','24859','225')" ondblclick="searchWord(2,127265)">ἀλήθειαν</grk><br><gloss>truth —</gloss></div></w></div></div></wg></div></cl></verse> <verse><vid id="v63.1.2" onclick="luV(2)">2</vid> <wg><div class='p'><wg><div class='p'><subclinfo>1:2.w1-w14</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127266" cl='c24860' sn='G1223' morph='PREP' class="G1223" onclick="luW(2,'127266','24860','1223','PREP')" onmouseover="hl1('127266','24860','1223')" onmouseout="hl0('127266','24860','1223')" ondblclick="searchWord(2,127266)">διὰ</grk><br><gloss>because of</gloss></div></w> <w><div class='w'><wordid>w2</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127267" cl='c24860' sn='G3588' morph='T-ASF' class="G3588" onclick="luW(2,'127267','24860','3588','T-ASF')" onmouseover="hl1('127267','24860','3588')" onmouseout="hl0('127267','24860','3588')" ondblclick="searchWord(2,127267)">τὴν</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127268" cl='c24860' sn='G225' morph='N-ASF' class="G225" onclick="luW(2,'127268','24860','225','N-ASF')" onmouseover="hl1('127268','24860','225')" onmouseout="hl0('127268','24860','225')" ondblclick="searchWord(2,127268)">ἀλήθειαν</grk><br><gloss>truth</gloss></div></w></div> <wg><div class='p'><wg><div class='p'><subclinfo>1:2.w4-w14</subclinfo></b><br><funcinfo>definer</funcinfo></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:2.w4-w7</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:2.w4-w5</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127269" cl='c24860' sn='G3588' morph='T-ASF' class="G3588" onclick="luW(2,'127269','24860','3588','T-ASF')" onmouseover="hl1('127269','24860','3588')" onmouseout="hl0('127269','24860','3588')" ondblclick="searchWord(2,127269)">τὴν</grk><br><gloss>-</gloss></div></w> <w><div class='w'><wordid>w5</wordid><br><funcinfo>head</funcinfo><br><grk id="w127270" cl='c24860' sn='G3306' morph='V-PAP-ASF' class="G3306" onclick="luW(2,'127270','24860','3306','V-PAP-ASF')" onmouseover="hl1('127270','24860','3306')" onmouseout="hl0('127270','24860','3306')" ondblclick="searchWord(2,127270)">μένουσαν</grk><br><gloss>abiding</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:2.w6-w7</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w6</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127271" cl='c24860' sn='G1722' morph='PREP' class="G1722" onclick="luW(2,'127271','24860','1722','PREP')" onmouseover="hl1('127271','24860','1722')" onmouseout="hl0('127271','24860','1722')" ondblclick="searchWord(2,127271)">ἐν</grk><br><gloss>in</gloss></div></w> <w><div class='w'><wordid>w7</wordid><br><funcinfo>head</funcinfo><br><grk id="w127272" cl='c24860' sn='G1473' morph='P-1DP' class="G1473" onclick="luW(2,'127272','24860','1473','P-1DP')" onmouseover="hl1('127272','24860','1473')" onmouseout="hl0('127272','24860','1473')" ondblclick="searchWord(2,127272)">ἡμῖν</grk><br><gloss>us</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:2.w8-w14</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:2.w8</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w8</wordid><br><funcinfo>head</funcinfo><br><grk id="w127273" cl='c24861' sn='G2532' morph='CONJ' class="G2532" onclick="luW(2,'127273','24861','2532','CONJ')" onmouseover="hl1('127273','24861','2532')" onmouseout="hl0('127273','24861','2532')" ondblclick="searchWord(2,127273)">καὶ</grk><br><gloss>and</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:2.w9-w10</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w9</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127274" cl='c24861' sn='G3326' morph='PREP' class="G3326" onclick="luW(2,'127274','24861','3326','PREP')" onmouseover="hl1('127274','24861','3326')" onmouseout="hl0('127274','24861','3326')" ondblclick="searchWord(2,127274)">μεθ᾽</grk><br><gloss>with</gloss></div></w> <w><div class='w'><wordid>w10</wordid><br><funcinfo>head</funcinfo><br><grk id="w127275" cl='c24861' sn='G1473' morph='P-1GP' class="G1473" onclick="luW(2,'127275','24861','1473','P-1GP')" onmouseover="hl1('127275','24861','1473')" onmouseout="hl0('127275','24861','1473')" ondblclick="searchWord(2,127275)">ἡμῶν</grk><br><gloss>us</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:2.w11</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w11</wordid><br><funcinfo>head</funcinfo><br><grk id="w127276" cl='c24861' sn='G1510' morph='V-FDI-3S' class="G1510" onclick="luW(2,'127276','24861','1510','V-FDI-3S')" onmouseover="hl1('127276','24861','1510')" onmouseout="hl0('127276','24861','1510')" ondblclick="searchWord(2,127276)">ἔσται</grk><br><gloss>that will be</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:2.w12-w14</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w12</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127277" cl='c24861' sn='G1519' morph='PREP' class="G1519" onclick="luW(2,'127277','24861','1519','PREP')" onmouseover="hl1('127277','24861','1519')" onmouseout="hl0('127277','24861','1519')" ondblclick="searchWord(2,127277)">εἰς</grk><br><gloss>to</gloss></div></w> <w><div class='w'><wordid>w13</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127278" cl='c24861' sn='G3588' morph='T-ASM' class="G3588" onclick="luW(2,'127278','24861','3588','T-ASM')" onmouseover="hl1('127278','24861','3588')" onmouseout="hl0('127278','24861','3588')" ondblclick="searchWord(2,127278)">τὸν</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w14</wordid><br><funcinfo>head</funcinfo><br><grk id="w127279" cl='c24861' sn='G165' morph='N-ASM' class="G165" onclick="luW(2,'127279','24861','165','N-ASM')" onmouseover="hl1('127279','24861','165')" onmouseout="hl0('127279','24861','165')" ondblclick="searchWord(2,127279)">αἰῶνα</grk><br><gloss>age:</gloss></div></w></div></div></wg></div></cl></div></wg></div></wg></div></cl></verse> <verse><vid id="v63.1.3" onclick="luV(3)">3</vid> <cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:3.w1-w21</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:3.w1</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>head</funcinfo><br><grk id="w127280" cl='c24862' sn='G1510' morph='V-FDI-3S' class="G1510" onclick="luW(3,'127280','24862','1510','V-FDI-3S')" onmouseover="hl1('127280','24862','1510')" onmouseout="hl0('127280','24862','1510')" ondblclick="searchWord(2,127280)">Ἔσται</grk><br><gloss>Will be</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w2-w3</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w2</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127281" cl='c24862' sn='G3326' morph='PREP' class="G3326" onclick="luW(3,'127281','24862','3326','PREP')" onmouseover="hl1('127281','24862','3326')" onmouseout="hl0('127281','24862','3326')" ondblclick="searchWord(2,127281)">μεθ᾽</grk><br><gloss>with</gloss></div></w> <w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127282" cl='c24862' sn='G1473' morph='P-1GP' class="G1473" onclick="luW(3,'127282','24862','1473','P-1GP')" onmouseover="hl1('127282','24862','1473')" onmouseout="hl0('127282','24862','1473')" ondblclick="searchWord(2,127282)">ἡμῶν</grk><br><gloss>us</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w4-w6</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w4</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>head</funcinfo><br><grk id="w127283" cl='c24862' sn='G5485' morph='N-NSF' class="G5485" onclick="luW(3,'127283','24862','5485','N-NSF')" onmouseover="hl1('127283','24862','5485')" onmouseout="hl0('127283','24862','5485')" ondblclick="searchWord(2,127283)">χάρις</grk><br><gloss>grace,</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w5</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w5</wordid><br><funcinfo>head</funcinfo><br><grk id="w127284" cl='c24862' sn='G1656' morph='N-NSN' class="G1656" onclick="luW(3,'127284','24862','1656','N-NSN')" onmouseover="hl1('127284','24862','1656')" onmouseout="hl0('127284','24862','1656')" ondblclick="searchWord(2,127284)">ἔλεος</grk><br><gloss>mercy,</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w6</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w6</wordid><br><funcinfo>head</funcinfo><br><grk id="w127285" cl='c24862' sn='G1515' morph='N-NSF' class="G1515" onclick="luW(3,'127285','24862','1515','N-NSF')" onmouseover="hl1('127285','24862','1515')" onmouseout="hl0('127285','24862','1515')" ondblclick="searchWord(2,127285)">εἰρήνη</grk><br><gloss>[and] peace</gloss></div></w></div></div></wg></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w7-w17</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w7-w9</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w7</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127286" cl='c24862' sn='G3844' morph='PREP' class="G3844" onclick="luW(3,'127286','24862','3844','PREP')" onmouseover="hl1('127286','24862','3844')" onmouseout="hl0('127286','24862','3844')" ondblclick="searchWord(2,127286)">παρὰ</grk><br><gloss>from</gloss></div></w> <w><div class='w'><wordid>w8</wordid><br><funcinfo>head</funcinfo><br><grk id="w127287" cl='c24862' sn='G2316' morph='N-GSM' class="G2316" onclick="luW(3,'127287','24862','2316','N-GSM')" onmouseover="hl1('127287','24862','2316')" onmouseout="hl0('127287','24862','2316')" ondblclick="searchWord(2,127287)">Θεοῦ</grk><br><gloss>God</gloss></div></w> <w><div class='w'><wordid>w9</wordid><br><funcinfo>definer</funcinfo><br><grk id="w127288" cl='c24862' sn='G3962' morph='N-GSM' class="G3962" onclick="luW(3,'127288','24862','3962','N-GSM')" onmouseover="hl1('127288','24862','3962')" onmouseout="hl0('127288','24862','3962')" ondblclick="searchWord(2,127288)">Πατρός</grk><br><gloss>[the] Father</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w10-w17</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w10</wordid><br><funcinfo>connector</funcinfo><br><grk id="w127289" cl='c24863' sn='G2532' morph='CONJ' class="G2532" onclick="luW(3,'127289','24863','2532','CONJ')" onmouseover="hl1('127289','24863','2532')" onmouseout="hl0('127289','24863','2532')" ondblclick="searchWord(2,127289)">καὶ</grk><br><gloss>and</gloss></div></w> <w><div class='w'><wordid>w11</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127290" cl='c24863' sn='G3844' morph='PREP' class="G3844" onclick="luW(3,'127290','24863','3844','PREP')" onmouseover="hl1('127290','24863','3844')" onmouseout="hl0('127290','24863','3844')" ondblclick="searchWord(2,127290)">παρὰ</grk><br><gloss>from</gloss></div></w> <w><div class='w'><wordid>w12</wordid><br><funcinfo>head</funcinfo><br><grk id="w127291" cl='c24863' sn='G2424' morph='N-GSM-P' class="G2424" onclick="luW(3,'127291','24863','2424','N-GSM-P')" onmouseover="hl1('127291','24863','2424')" onmouseout="hl0('127291','24863','2424')" ondblclick="searchWord(2,127291)">Ἰησοῦ</grk><br><gloss>Jesus</gloss></div></w></div> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w13-w17</subclinfo></b><br><funcinfo>definer</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w13</wordid><br><funcinfo>&nbsp;</funcinfo><br><grk id="w127292" cl='c24863' sn='G5547' morph='N-GSM-T' class="G5547" onclick="luW(3,'127292','24863','5547','N-GSM-T')" onmouseover="hl1('127292','24863','5547')" onmouseout="hl0('127292','24863','5547')" ondblclick="searchWord(2,127292)">Χριστοῦ</grk><br><gloss>Christ,</gloss></div></w></div> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w14-w17</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w14</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127293" cl='c24863' sn='G3588' morph='T-GSM' class="G3588" onclick="luW(3,'127293','24863','3588','T-GSM')" onmouseover="hl1('127293','24863','3588')" onmouseout="hl0('127293','24863','3588')" ondblclick="searchWord(2,127293)">τοῦ</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w15</wordid><br><funcinfo>head</funcinfo><br><grk id="w127294" cl='c24863' sn='G5207' morph='N-GSM' class="G5207" onclick="luW(3,'127294','24863','5207','N-GSM')" onmouseover="hl1('127294','24863','5207')" onmouseout="hl0('127294','24863','5207')" ondblclick="searchWord(2,127294)">Υἱοῦ</grk><br><gloss>Son</gloss></div></w></div> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w16-w17</subclinfo></b><br><funcinfo>qualifier</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w16</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127295" cl='c24863' sn='G3588' morph='T-GSM' class="G3588" onclick="luW(3,'127295','24863','3588','T-GSM')" onmouseover="hl1('127295','24863','3588')" onmouseout="hl0('127295','24863','3588')" ondblclick="searchWord(2,127295)">τοῦ</grk><br><gloss>of the</gloss></div></w> <w><div class='w'><wordid>w17</wordid><br><funcinfo>head</funcinfo><br><grk id="w127296" cl='c24863' sn='G3962' morph='N-GSM' class="G3962" onclick="luW(3,'127296','24863','3962','N-GSM')" onmouseover="hl1('127296','24863','3962')" onmouseout="hl0('127296','24863','3962')" ondblclick="searchWord(2,127296)">Πατρός</grk><br><gloss>Father,</gloss></div></w></div></div></wg></div></wg></div></wg></div></wg></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w18-w21</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w18-w19</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w18</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127297" cl='c24863' sn='G1722' morph='PREP' class="G1722" onclick="luW(3,'127297','24863','1722','PREP')" onmouseover="hl1('127297','24863','1722')" onmouseout="hl0('127297','24863','1722')" ondblclick="searchWord(2,127297)">ἐν</grk><br><gloss>in</gloss></div></w> <w><div class='w'><wordid>w19</wordid><br><funcinfo>head</funcinfo><br><grk id="w127298" cl='c24863' sn='G225' morph='N-DSF' class="G225" onclick="luW(3,'127298','24863','225','N-DSF')" onmouseover="hl1('127298','24863','225')" onmouseout="hl0('127298','24863','225')" ondblclick="searchWord(2,127298)">ἀληθείᾳ</grk><br><gloss>truth</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:3.w20-w21</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w20</wordid><br><funcinfo>connector</funcinfo><br><grk id="w127299" cl='c24863' sn='G2532' morph='CONJ' class="G2532" onclick="luW(3,'127299','24863','2532','CONJ')" onmouseover="hl1('127299','24863','2532')" onmouseout="hl0('127299','24863','2532')" ondblclick="searchWord(2,127299)">καὶ</grk><br><gloss>and</gloss></div></w> <w><div class='w'><wordid>w21</wordid><br><funcinfo>head</funcinfo><br><grk id="w127300" cl='c24863' sn='G26' morph='N-DSF' class="G26" onclick="luW(3,'127300','24863','26','N-DSF')" onmouseover="hl1('127300','24863','26')" onmouseout="hl0('127300','24863','26')" ondblclick="searchWord(2,127300)">ἀγάπῃ</grk><br><gloss>love.</gloss></div></w></div></div></wg></div></wg></div></cl></verse> <verse><vid id="v63.1.4" onclick="luV(4)">4</vid> <cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:4.w1-w2</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:4.w1</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>head</funcinfo><br><grk id="w127301" cl='c24864' sn='G5463' morph='V-2AOI-1S' class="G5463" onclick="luW(4,'127301','24864','5463','V-2AOI-1S')" onmouseover="hl1('127301','24864','5463')" onmouseout="hl0('127301','24864','5463')" ondblclick="searchWord(2,127301)">Ἐχάρην</grk><br><gloss>I rejoiced</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:4.w2</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w2</wordid><br><funcinfo>head</funcinfo><br><grk id="w127302" cl='c24864' sn='G3029' morph='ADV' class="G3029" onclick="luW(4,'127302','24864','3029','ADV')" onmouseover="hl1('127302','24864','3029')" onmouseout="hl0('127302','24864','3029')" ondblclick="searchWord(2,127302)">λίαν</grk><br><gloss>exceedingly</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:4.w3-w11</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:4.w1-w2</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:4.w3</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127303" cl='c24865' sn='G3754' morph='CONJ' class="G3754" onclick="luW(4,'127303','24865','3754','CONJ')" onmouseover="hl1('127303','24865','3754')" onmouseout="hl0('127303','24865','3754')" ondblclick="searchWord(2,127303)">ὅτι</grk><br><gloss>that</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:4.w4</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>head</funcinfo><br><grk id="w127304" cl='c24865' sn='G2147' morph='V-RAI-1S' class="G2147" onclick="luW(4,'127304','24865','2147','V-RAI-1S')" onmouseover="hl1('127304','24865','2147')" onmouseout="hl0('127304','24865','2147')" ondblclick="searchWord(2,127304)">εὕρηκα</grk><br><gloss>I have found</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:4.w5-w8</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w5</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127305" cl='c24865' sn='G1537' morph='PREP' class="G1537" onclick="luW(4,'127305','24865','1537','PREP')" onmouseover="hl1('127305','24865','1537')" onmouseout="hl0('127305','24865','1537')" ondblclick="searchWord(2,127305)">ἐκ</grk><br><gloss>[some] of</gloss></div></w> <w><div class='w'><wordid>w6</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127306" cl='c24865' sn='G3588' morph='T-GPN' class="G3588" onclick="luW(4,'127306','24865','3588','T-GPN')" onmouseover="hl1('127306','24865','3588')" onmouseout="hl0('127306','24865','3588')" ondblclick="searchWord(2,127306)">τῶν</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w7</wordid><br><funcinfo>head</funcinfo><br><grk id="w127307" cl='c24865' sn='G5043' morph='N-GPN' class="G5043" onclick="luW(4,'127307','24865','5043','N-GPN')" onmouseover="hl1('127307','24865','5043')" onmouseout="hl0('127307','24865','5043')" ondblclick="searchWord(2,127307)">τέκνων</grk><br><gloss>children</gloss></div></w> <w><div class='w'><wordid>w8</wordid><br><funcinfo>qualifier</funcinfo><br><grk id="w127308" cl='c24865' sn='G4771' morph='P-2GS' class="G4771" onclick="luW(4,'127308','24865','4771','P-2GS')" onmouseover="hl1('127308','24865','4771')" onmouseout="hl0('127308','24865','4771')" ondblclick="searchWord(2,127308)">σου</grk><br><gloss>of you</gloss></div></w></div></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>complement</funcinfo> <b><clinfo>1:4.w9-w11</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:4.w9</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w9</wordid><br><funcinfo>head</funcinfo><br><grk id="w127309" cl='c24866' sn='G4043' morph='V-PAP-APM' class="G4043" onclick="luW(4,'127309','24866','4043','V-PAP-APM')" onmouseover="hl1('127309','24866','4043')" onmouseout="hl0('127309','24866','4043')" ondblclick="searchWord(2,127309)">περιπατοῦντας</grk><br><gloss>walking</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:4.w10-w11</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w10</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127310" cl='c24866' sn='G1722' morph='PREP' class="G1722" onclick="luW(4,'127310','24866','1722','PREP')" onmouseover="hl1('127310','24866','1722')" onmouseout="hl0('127310','24866','1722')" ondblclick="searchWord(2,127310)">ἐν</grk><br><gloss>in</gloss></div></w> <w><div class='w'><wordid>w11</wordid><br><funcinfo>head</funcinfo><br><grk id="w127311" cl='c24866' sn='G225' morph='N-DSF' class="G225" onclick="luW(4,'127311','24866','225','N-DSF')" onmouseover="hl1('127311','24866','225')" onmouseout="hl0('127311','24866','225')" ondblclick="searchWord(2,127311)">ἀληθείᾳ</grk><br><gloss>truth,</gloss></div></w></div></div></wg></div></cl></div></cl><cl><div class='c'><sup><cllevel>°°°</cllevel> <b><clinfo>1:4.w12-w17</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:4.w3-w11</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:4.w12</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w12</wordid><br><funcinfo>head</funcinfo><br><grk id="w127312" cl='c24867' sn='G2531' morph='CONJ' class="G2531" onclick="luW(4,'127312','24867','2531','CONJ')" onmouseover="hl1('127312','24867','2531')" onmouseout="hl0('127312','24867','2531')" ondblclick="searchWord(2,127312)">καθὼς</grk><br><gloss>just as</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:4.w13</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w13</wordid><br><funcinfo>head</funcinfo><br><grk id="w127313" cl='c24867' sn='G1785' morph='N-ASF' class="G1785" onclick="luW(4,'127313','24867','1785','N-ASF')" onmouseover="hl1('127313','24867','1785')" onmouseout="hl0('127313','24867','1785')" ondblclick="searchWord(2,127313)">ἐντολὴν</grk><br><gloss>commandment</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:4.w14</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w14</wordid><br><funcinfo>head</funcinfo><br><grk id="w127314" cl='c24867' sn='G2983' morph='V-2AAI-1P' class="G2983" onclick="luW(4,'127314','24867','2983','V-2AAI-1P')" onmouseover="hl1('127314','24867','2983')" onmouseout="hl0('127314','24867','2983')" ondblclick="searchWord(2,127314)">ἐλάβομεν</grk><br><gloss>we received</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:4.w15-w17</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w15</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127315" cl='c24867' sn='G3844' morph='PREP' class="G3844" onclick="luW(4,'127315','24867','3844','PREP')" onmouseover="hl1('127315','24867','3844')" onmouseout="hl0('127315','24867','3844')" ondblclick="searchWord(2,127315)">παρὰ</grk><br><gloss>from</gloss></div></w> <w><div class='w'><wordid>w16</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127316" cl='c24867' sn='G3588' morph='T-GSM' class="G3588" onclick="luW(4,'127316','24867','3588','T-GSM')" onmouseover="hl1('127316','24867','3588')" onmouseout="hl0('127316','24867','3588')" ondblclick="searchWord(2,127316)">τοῦ</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w17</wordid><br><funcinfo>head</funcinfo><br><grk id="w127317" cl='c24867' sn='G3962' morph='N-GSM' class="G3962" onclick="luW(4,'127317','24867','3962','N-GSM')" onmouseover="hl1('127317','24867','3962')" onmouseout="hl0('127317','24867','3962')" ondblclick="searchWord(2,127317)">Πατρός</grk><br><gloss>Father.</gloss></div></w></div></div></wg></div></cl></verse> <verse><vid id="v63.1.5" onclick="luV(5)">5</vid> <cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:5.w1-w16</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:5.w1</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>head</funcinfo><br><grk id="w127318" cl='c24868' sn='G2532' morph='CONJ' class="G2532" onclick="luW(5,'127318','24868','2532','CONJ')" onmouseover="hl1('127318','24868','2532')" onmouseout="hl0('127318','24868','2532')" ondblclick="searchWord(2,127318)">καὶ</grk><br><gloss>And</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w2</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w2</wordid><br><funcinfo>head</funcinfo><br><grk id="w127319" cl='c24868' sn='G3568' morph='ADV' class="G3568" onclick="luW(5,'127319','24868','3568','ADV')" onmouseover="hl1('127319','24868','3568')" onmouseout="hl0('127319','24868','3568')" ondblclick="searchWord(2,127319)">νῦν</grk><br><gloss>now</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w3</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127320" cl='c24868' sn='G2065' morph='V-PAI-1S' class="G2065" onclick="luW(5,'127320','24868','2065','V-PAI-1S')" onmouseover="hl1('127320','24868','2065')" onmouseout="hl0('127320','24868','2065')" ondblclick="searchWord(2,127320)">ἐρωτῶ</grk><br><gloss>I implore</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w4</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>head</funcinfo><br><grk id="w127321" cl='c24868' sn='G4771' morph='P-2AS' class="G4771" onclick="luW(5,'127321','24868','4771','P-2AS')" onmouseover="hl1('127321','24868','4771')" onmouseout="hl0('127321','24868','4771')" ondblclick="searchWord(2,127321)">σε</grk><br><gloss>you,</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w5</subclinfo></b><br><funcinfo>addressee</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w5</wordid><br><funcinfo>head</funcinfo><br><grk id="w127322" cl='c24868' sn='G2959' morph='N-VSF' class="G2959" onclick="luW(5,'127322','24868','2959','N-VSF')" onmouseover="hl1('127322','24868','2959')" onmouseout="hl0('127322','24868','2959')" ondblclick="searchWord(2,127322)">κυρία</grk><br><gloss>lady,</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w6-w16</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:5.w6-w11</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:5.w6-w7_2</subclinfo></b><br><funcinfo>predicator</funcinfo><br><funcinfo>→</funcinfo> <i><clinfo>1:5.w9</clinfo></i></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w6-w7</subclinfo></b><br><funcinfo>specifier</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w6</wordid><br><funcinfo>qualifier</funcinfo><br><grk id="w127323" cl='c24869' sn='G3756' morph='PRT-N' class="G3756" onclick="luW(5,'127323','24869','3756','PRT-N')" onmouseover="hl1('127323','24869','3756')" onmouseout="hl0('127323','24869','3756')" ondblclick="searchWord(2,127323)">οὐχ</grk><br><gloss>not</gloss></div></w> <w><div class='w'><wordid>w7</wordid><br><funcinfo>head</funcinfo><br><grk id="w127324" cl='c24869' sn='G5613' morph='CONJ' class="G5613" onclick="luW(5,'127324','24869','5613','CONJ')" onmouseover="hl1('127324','24869','5613')" onmouseout="hl0('127324','24869','5613')" ondblclick="searchWord(2,127324)">ὡς</grk><br><gloss>as</gloss></div></w></div></div></wg></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w8</subclinfo></b><br><funcinfo>complement</funcinfo><br><funcinfo>→</funcinfo> <i><clinfo>1:5.w11</clinfo></i></div></wg> <div class='wrap'><w><div class='w'><wordid>w8</wordid><br><funcinfo>head</funcinfo><br><grk id="w127325" cl='c24869' sn='G1785' morph='N-ASF' class="G1785" onclick="luW(5,'127325','24869','1785','N-ASF')" onmouseover="hl1('127325','24869','1785')" onmouseout="hl0('127325','24869','1785')" ondblclick="searchWord(2,127325)">ἐντολὴν</grk><br><gloss>a commandment</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w9</subclinfo></b><br>&nbsp;<br><i><clinfo>1:5.w6-w7_2</clinfo></i> <funcinfo>←</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w9</wordid><br><funcinfo>head</funcinfo><br><grk id="w127326" cl='c24869' sn='G1125' morph='V-PAP-NSM' class="G1125" onclick="luW(5,'127326','24869','1125','V-PAP-NSM')" onmouseover="hl1('127326','24869','1125')" onmouseout="hl0('127326','24869','1125')" ondblclick="searchWord(2,127326)">γράφων</grk><br><gloss>I am writing</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w10</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w10</wordid><br><funcinfo>head</funcinfo><br><grk id="w127327" cl='c24869' sn='G4771' morph='P-2DS' class="G4771" onclick="luW(5,'127327','24869','4771','P-2DS')" onmouseover="hl1('127327','24869','4771')" onmouseout="hl0('127327','24869','4771')" ondblclick="searchWord(2,127327)">σοι</grk><br><gloss>to you</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w11</subclinfo></b><br>&nbsp;<br><i><clinfo>1:5.w8</clinfo></i> <funcinfo>←</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w11</wordid><br><funcinfo>definer</funcinfo><br><grk id="w127328" cl='c24869' sn='G2537' morph='A-ASF' class="G2537" onclick="luW(5,'127328','24869','2537','A-ASF')" onmouseover="hl1('127328','24869','2537')" onmouseout="hl0('127328','24869','2537')" ondblclick="searchWord(2,127328)">καινὴν</grk><br><gloss>new,</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:5.w12-w16</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:5.w12</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w12</wordid><br><funcinfo>head</funcinfo><br><grk id="w127329" cl='c24870' sn='G235' morph='CONJ' class="G235" onclick="luW(5,'127329','24870','235','CONJ')" onmouseover="hl1('127329','24870','235')" onmouseout="hl0('127329','24870','235')" ondblclick="searchWord(2,127329)">ἀλλὰ</grk><sup><a href="javascript:void(0)" onclick="word('127329')">=</a></sup><br><gloss>but</gloss></div></w></div></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>complement</funcinfo> <b><clinfo>1:5.w13-w16</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:5.w13</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w13</wordid><br><funcinfo>head</funcinfo><br><grk id="w127330" cl='c24870' sn='G3739' morph='R-ASF' class="G3739" onclick="luW(5,'127330','24870','3739','R-ASF')" onmouseover="hl1('127330','24870','3739')" onmouseout="hl0('127330','24870','3739')" ondblclick="searchWord(2,127330)">ἣν</grk><br><gloss>that which</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w14</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w14</wordid><br><funcinfo>head</funcinfo><br><grk id="w127331" cl='c24870' sn='G2192' morph='V-IAI-1P' class="G2192" onclick="luW(5,'127331','24870','2192','V-IAI-1P')" onmouseover="hl1('127331','24870','2192')" onmouseout="hl0('127331','24870','2192')" ondblclick="searchWord(2,127331)">εἴχομεν</grk><br><gloss>we have had</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w15-w16</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w15</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127332" cl='c24870' sn='G575' morph='PREP' class="G575" onclick="luW(5,'127332','24870','575','PREP')" onmouseover="hl1('127332','24870','575')" onmouseout="hl0('127332','24870','575')" ondblclick="searchWord(2,127332)">ἀπ᾽</grk><br><gloss>from</gloss></div></w> <w><div class='w'><wordid>w16</wordid><br><funcinfo>head</funcinfo><br><grk id="w127333" cl='c24870' sn='G746' morph='N-GSF' class="G746" onclick="luW(5,'127333','24870','746','N-GSF')" onmouseover="hl1('127333','24870','746')" onmouseout="hl0('127333','24870','746')" ondblclick="searchWord(2,127333)">ἀρχῆς</grk><br><gloss>[the] beginning,</gloss></div></w></div></div></wg></div></cl></div></cl></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:5.w17-w19</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:5.w1-w16</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:5.w17</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w17</wordid><br><funcinfo>head</funcinfo><br><grk id="w127334" cl='c24871' sn='G2443' morph='CONJ' class="G2443" onclick="luW(5,'127334','24871','2443','CONJ')" onmouseover="hl1('127334','24871','2443')" onmouseout="hl0('127334','24871','2443')" ondblclick="searchWord(2,127334)">ἵνα</grk><br><gloss>that</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w18</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w18</wordid><br><funcinfo>head</funcinfo><br><grk id="w127335" cl='c24871' sn='G25' morph='V-PAS-1P' class="G25" onclick="luW(5,'127335','24871','25','V-PAS-1P')" onmouseover="hl1('127335','24871','25')" onmouseout="hl0('127335','24871','25')" ondblclick="searchWord(2,127335)">ἀγαπῶμεν</grk><br><gloss>we should love</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:5.w19</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w19</wordid><br><funcinfo>head</funcinfo><br><grk id="w127336" cl='c24871' sn='G240' morph='C-APM' class="G240" onclick="luW(5,'127336','24871','240','C-APM')" onmouseover="hl1('127336','24871','240')" onmouseout="hl0('127336','24871','240')" ondblclick="searchWord(2,127336)">ἀλλήλους</grk><br><gloss>one another.</gloss></div></w></div></div></wg></div></cl></verse> <verse><vid id="v63.1.6" onclick="luV(6)">6</vid> <cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:6.w1-w5</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:6.w1</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>head</funcinfo><br><grk id="w127337" cl='c24872' sn='G2532' morph='CONJ' class="G2532" onclick="luW(6,'127337','24872','2532','CONJ')" onmouseover="hl1('127337','24872','2532')" onmouseout="hl0('127337','24872','2532')" ondblclick="searchWord(2,127337)">καὶ</grk><br><gloss>And</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w2</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w2</wordid><br><funcinfo>head</funcinfo><br><grk id="w127338" cl='c24872' sn='G3778' morph='D-NSF' class="G3778" onclick="luW(6,'127338','24872','3778','D-NSF')" onmouseover="hl1('127338','24872','3778')" onmouseout="hl0('127338','24872','3778')" ondblclick="searchWord(2,127338)">αὕτη</grk><br><gloss>this</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w3</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127339" cl='c24872' sn='G1510' morph='V-PAI-3S' class="G1510" onclick="luW(6,'127339','24872','1510','V-PAI-3S')" onmouseover="hl1('127339','24872','1510')" onmouseout="hl0('127339','24872','1510')" ondblclick="searchWord(2,127339)">ἐστὶν</grk><br><gloss>is</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w4-w5</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127340" cl='c24872' sn='G3588' morph='T-NSF' class="G3588" onclick="luW(6,'127340','24872','3588','T-NSF')" onmouseover="hl1('127340','24872','3588')" onmouseout="hl0('127340','24872','3588')" ondblclick="searchWord(2,127340)">ἡ</grk><br><gloss>-</gloss></div></w> <w><div class='w'><wordid>w5</wordid><br><funcinfo>head</funcinfo><br><grk id="w127341" cl='c24872' sn='G26' morph='N-NSF' class="G26" onclick="luW(6,'127341','24872','26','N-NSF')" onmouseover="hl1('127341','24872','26')" onmouseout="hl0('127341','24872','26')" ondblclick="searchWord(2,127341)">ἀγάπη</grk><br><gloss>love,</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:6.w6-w11</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:6.w1-w5</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:6.w6</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w6</wordid><br><funcinfo>head</funcinfo><br><grk id="w127342" cl='c24873' sn='G2443' morph='ADV' class="G2443" onclick="luW(6,'127342','24873','2443','ADV')" onmouseover="hl1('127342','24873','2443')" onmouseout="hl0('127342','24873','2443')" ondblclick="searchWord(2,127342)">ἵνα</grk><br><gloss>that</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w7</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w7</wordid><br><funcinfo>head</funcinfo><br><grk id="w127343" cl='c24873' sn='G4043' morph='V-PAS-1P' class="G4043" onclick="luW(6,'127343','24873','4043','V-PAS-1P')" onmouseover="hl1('127343','24873','4043')" onmouseout="hl0('127343','24873','4043')" ondblclick="searchWord(2,127343)">περιπατῶμεν</grk><br><gloss>we should walk</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w8-w11</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w8</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127344" cl='c24873' sn='G2596' morph='PREP' class="G2596" onclick="luW(6,'127344','24873','2596','PREP')" onmouseover="hl1('127344','24873','2596')" onmouseout="hl0('127344','24873','2596')" ondblclick="searchWord(2,127344)">κατὰ</grk><br><gloss>according to</gloss></div></w> <w><div class='w'><wordid>w9</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127345" cl='c24873' sn='G3588' morph='T-APF' class="G3588" onclick="luW(6,'127345','24873','3588','T-APF')" onmouseover="hl1('127345','24873','3588')" onmouseout="hl0('127345','24873','3588')" ondblclick="searchWord(2,127345)">τὰς</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w10</wordid><br><funcinfo>head</funcinfo><br><grk id="w127346" cl='c24873' sn='G1785' morph='N-APF' class="G1785" onclick="luW(6,'127346','24873','1785','N-APF')" onmouseover="hl1('127346','24873','1785')" onmouseout="hl0('127346','24873','1785')" ondblclick="searchWord(2,127346)">ἐντολὰς</grk><br><gloss>commandments</gloss></div></w> <w><div class='w'><wordid>w11</wordid><br><funcinfo>qualifier</funcinfo><br><grk id="w127347" cl='c24873' sn='G846' morph='P-GSM' class="G846" onclick="luW(6,'127347','24873','846','P-GSM')" onmouseover="hl1('127347','24873','846')" onmouseout="hl0('127347','24873','846')" ondblclick="searchWord(2,127347)">αὐτοῦ</grk><br><gloss>of Him.</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:6.w12-w15</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:6.w12</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w12</wordid><br><funcinfo>head</funcinfo><br><grk id="w127348" cl='c24874' sn='G3778' morph='D-NSF' class="G3778" onclick="luW(6,'127348','24874','3778','D-NSF')" onmouseover="hl1('127348','24874','3778')" onmouseout="hl0('127348','24874','3778')" ondblclick="searchWord(2,127348)">αὕτη</grk><br><gloss>This</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w13-w14</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w13</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127349" cl='c24874' sn='G3588' morph='T-NSF' class="G3588" onclick="luW(6,'127349','24874','3588','T-NSF')" onmouseover="hl1('127349','24874','3588')" onmouseout="hl0('127349','24874','3588')" ondblclick="searchWord(2,127349)">ἡ</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w14</wordid><br><funcinfo>head</funcinfo><br><grk id="w127350" cl='c24874' sn='G1785' morph='N-NSF' class="G1785" onclick="luW(6,'127350','24874','1785','N-NSF')" onmouseover="hl1('127350','24874','1785')" onmouseout="hl0('127350','24874','1785')" ondblclick="searchWord(2,127350)">ἐντολή</grk><br><gloss>commandment</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w15</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w15</wordid><br><funcinfo>head</funcinfo><br><grk id="w127351" cl='c24874' sn='G1510' morph='V-PAI-3S' class="G1510" onclick="luW(6,'127351','24874','1510','V-PAI-3S')" onmouseover="hl1('127351','24874','1510')" onmouseout="hl0('127351','24874','1510')" ondblclick="searchWord(2,127351)">ἐστιν</grk><br><gloss>is</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:6.w16-w19</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:6.w12-w15</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:6.w16</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w16</wordid><br><funcinfo>head</funcinfo><br><grk id="w127352" cl='c24875' sn='G2531' morph='CONJ' class="G2531" onclick="luW(6,'127352','24875','2531','CONJ')" onmouseover="hl1('127352','24875','2531')" onmouseout="hl0('127352','24875','2531')" ondblclick="searchWord(2,127352)">καθὼς</grk><br><gloss>just as</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w17</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w17</wordid><br><funcinfo>head</funcinfo><br><grk id="w127353" cl='c24875' sn='G191' morph='V-AAI-2P' class="G191" onclick="luW(6,'127353','24875','191','V-AAI-2P')" onmouseover="hl1('127353','24875','191')" onmouseout="hl0('127353','24875','191')" ondblclick="searchWord(2,127353)">ἠκούσατε</grk><br><gloss>you have heard</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w18-w19</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w18</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127354" cl='c24875' sn='G575' morph='PREP' class="G575" onclick="luW(6,'127354','24875','575','PREP')" onmouseover="hl1('127354','24875','575')" onmouseout="hl0('127354','24875','575')" ondblclick="searchWord(2,127354)">ἀπ᾽</grk><br><gloss>from</gloss></div></w> <w><div class='w'><wordid>w19</wordid><br><funcinfo>head</funcinfo><br><grk id="w127355" cl='c24875' sn='G746' morph='N-GSF' class="G746" onclick="luW(6,'127355','24875','746','N-GSF')" onmouseover="hl1('127355','24875','746')" onmouseout="hl0('127355','24875','746')" ondblclick="searchWord(2,127355)">ἀρχῆς</grk><br><gloss>[the] beginning,</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:6.w20-w23</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:6.w12-w15</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:6.w20</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w20</wordid><br><funcinfo>head</funcinfo><br><grk id="w127356" cl='c24876' sn='G2443' morph='ADV' class="G2443" onclick="luW(6,'127356','24876','2443','ADV')" onmouseover="hl1('127356','24876','2443')" onmouseout="hl0('127356','24876','2443')" ondblclick="searchWord(2,127356)">ἵνα</grk><br><gloss>so that</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w21-w22</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w21</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127357" cl='c24876' sn='G1722' morph='PREP' class="G1722" onclick="luW(6,'127357','24876','1722','PREP')" onmouseover="hl1('127357','24876','1722')" onmouseout="hl0('127357','24876','1722')" ondblclick="searchWord(2,127357)">ἐν</grk><br><gloss>in</gloss></div></w> <w><div class='w'><wordid>w22</wordid><br><funcinfo>head</funcinfo><br><grk id="w127358" cl='c24876' sn='G846' morph='P-DSF' class="G846" onclick="luW(6,'127358','24876','846','P-DSF')" onmouseover="hl1('127358','24876','846')" onmouseout="hl0('127358','24876','846')" ondblclick="searchWord(2,127358)">αὐτῇ</grk><br><gloss>it</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:6.w23</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w23</wordid><br><funcinfo>head</funcinfo><br><grk id="w127359" cl='c24876' sn='G4043' morph='V-PAS-2P' class="G4043" onclick="luW(6,'127359','24876','4043','V-PAS-2P')" onmouseover="hl1('127359','24876','4043')" onmouseout="hl0('127359','24876','4043')" ondblclick="searchWord(2,127359)">περιπατῆτε</grk><br><gloss>you should walk.</gloss></div></w></div></div></wg></div></cl></verse> <verse><vid id="v63.1.7" onclick="luV(7)">7</vid> <cl><div class='c'><sup><cllevel>°°°</cllevel> <b><clinfo>1:7.w1-w7</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:6.w20-w23</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:7.w1</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>head</funcinfo><br><grk id="w127360" cl='c24877' sn='G3754' morph='CONJ' class="G3754" onclick="luW(7,'127360','24877','3754','CONJ')" onmouseover="hl1('127360','24877','3754')" onmouseout="hl0('127360','24877','3754')" ondblclick="searchWord(2,127360)">Ὅτι</grk><br><gloss>For</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w2-w3</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w2</wordid><br><funcinfo>definer</funcinfo><br><grk id="w127361" cl='c24877' sn='G4183' morph='A-NPM' class="G4183" onclick="luW(7,'127361','24877','4183','A-NPM')" onmouseover="hl1('127361','24877','4183')" onmouseout="hl0('127361','24877','4183')" ondblclick="searchWord(2,127361)">πολλοὶ</grk><br><gloss>many</gloss></div></w> <w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127362" cl='c24877' sn='G4108' morph='A-NPM' class="G4108" onclick="luW(7,'127362','24877','4108','A-NPM')" onmouseover="hl1('127362','24877','4108')" onmouseout="hl0('127362','24877','4108')" ondblclick="searchWord(2,127362)">πλάνοι</grk><br><gloss>deceivers</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w4</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>head</funcinfo><br><grk id="w127363" cl='c24877' sn='G1831' morph='V-2AAI-3P' class="G1831" onclick="luW(7,'127363','24877','1831','V-2AAI-3P')" onmouseover="hl1('127363','24877','1831')" onmouseout="hl0('127363','24877','1831')" ondblclick="searchWord(2,127363)">ἐξῆλθον</grk><br><gloss>have entered</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w5-w7</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w5</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127364" cl='c24877' sn='G1519' morph='PREP' class="G1519" onclick="luW(7,'127364','24877','1519','PREP')" onmouseover="hl1('127364','24877','1519')" onmouseout="hl0('127364','24877','1519')" ondblclick="searchWord(2,127364)">εἰς</grk><br><gloss>into</gloss></div></w> <w><div class='w'><wordid>w6</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127365" cl='c24877' sn='G3588' morph='T-ASM' class="G3588" onclick="luW(7,'127365','24877','3588','T-ASM')" onmouseover="hl1('127365','24877','3588')" onmouseout="hl0('127365','24877','3588')" ondblclick="searchWord(2,127365)">τὸν</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w7</wordid><br><funcinfo>head</funcinfo><br><grk id="w127366" cl='c24877' sn='G2889' morph='N-ASM' class="G2889" onclick="luW(7,'127366','24877','2889','N-ASM')" onmouseover="hl1('127366','24877','2889')" onmouseout="hl0('127366','24877','2889')" ondblclick="searchWord(2,127366)">κόσμον</grk><br><gloss>world,</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:7.w8-w15_2</clinfo></b></sup><br><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>subject</funcinfo> <b><clinfo>1:7.w8-w15</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:7.w8</subclinfo></b><br><funcinfo>predicator</funcinfo><br><funcinfo>→</funcinfo> <i><clinfo>1:7.w10</clinfo></i></div></wg> <div class='wrap'><w><div class='w'><wordid>w8</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127367" cl='c24878' sn='G3588' morph='T-NPM' class="G3588" onclick="luW(7,'127367','24878','3588','T-NPM')" onmouseover="hl1('127367','24878','3588')" onmouseout="hl0('127367','24878','3588')" ondblclick="searchWord(2,127367)">οἱ</grk><br><gloss>those</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w9</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w9</wordid><br><funcinfo>head</funcinfo><br><grk id="w127368" cl='c24878' sn='G3361' morph='PRT-N' class="G3361" onclick="luW(7,'127368','24878','3361','PRT-N')" onmouseover="hl1('127368','24878','3361')" onmouseout="hl0('127368','24878','3361')" ondblclick="searchWord(2,127368)">μὴ</grk><br><gloss>not</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w10</subclinfo></b><br>&nbsp;<br><i><clinfo>1:7.w8</clinfo></i> <funcinfo>←</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w10</wordid><br><funcinfo>head</funcinfo><br><grk id="w127369" cl='c24878' sn='G3670' morph='V-PAP-NPM' class="G3670" onclick="luW(7,'127369','24878','3670','V-PAP-NPM')" onmouseover="hl1('127369','24878','3670')" onmouseout="hl0('127369','24878','3670')" ondblclick="searchWord(2,127369)">ὁμολογοῦντες</grk><br><gloss>confessing</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w11</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w11</wordid><br><funcinfo>head</funcinfo><br><grk id="w127370" cl='c24878' sn='G2424' morph='N-ASM-P' class="G2424" onclick="luW(7,'127370','24878','2424','N-ASM-P')" onmouseover="hl1('127370','24878','2424')" onmouseout="hl0('127370','24878','2424')" ondblclick="searchWord(2,127370)">Ἰησοῦν</grk><br><gloss>Jesus</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w12-w15</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w12</wordid><br><funcinfo>head</funcinfo><br><grk id="w127371" cl='c24878' sn='G5547' morph='N-ASM-T' class="G5547" onclick="luW(7,'127371','24878','5547','N-ASM-T')" onmouseover="hl1('127371','24878','5547')" onmouseout="hl0('127371','24878','5547')" ondblclick="searchWord(2,127371)">Χριστὸν</grk><br><gloss>Christ</gloss></div></w></div><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>definer</funcinfo> <b><clinfo>1:7.w13-w15</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:7.w13</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w13</wordid><br><funcinfo>head</funcinfo><br><grk id="w127372" cl='c24878' sn='G2064' morph='V-PNP-ASM' class="G2064" onclick="luW(7,'127372','24878','2064','V-PNP-ASM')" onmouseover="hl1('127372','24878','2064')" onmouseout="hl0('127372','24878','2064')" ondblclick="searchWord(2,127372)">ἐρχόμενον</grk><br><gloss>coming</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w14-w15</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w14</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127373" cl='c24878' sn='G1722' morph='PREP' class="G1722" onclick="luW(7,'127373','24878','1722','PREP')" onmouseover="hl1('127373','24878','1722')" onmouseout="hl0('127373','24878','1722')" ondblclick="searchWord(2,127373)">ἐν</grk><br><gloss>in</gloss></div></w> <w><div class='w'><wordid>w15</wordid><br><funcinfo>head</funcinfo><br><grk id="w127374" cl='c24878' sn='G4561' morph='N-DSF' class="G4561" onclick="luW(7,'127374','24878','4561','N-DSF')" onmouseover="hl1('127374','24878','4561')" onmouseout="hl0('127374','24878','4561')" ondblclick="searchWord(2,127374)">σαρκί</grk><br><gloss>flesh.</gloss></div></w></div></div></wg></div></cl></div></wg></div></cl></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:7.w16-w22</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:7.w16</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w16</wordid><br><funcinfo>head</funcinfo><br><grk id="w127375" cl='c24879' sn='G3778' morph='D-NSM' class="G3778" onclick="luW(7,'127375','24879','3778','D-NSM')" onmouseover="hl1('127375','24879','3778')" onmouseout="hl0('127375','24879','3778')" ondblclick="searchWord(2,127375)">οὗτός</grk><br><gloss>This</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w17</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w17</wordid><br><funcinfo>head</funcinfo><br><grk id="w127376" cl='c24879' sn='G1510' morph='V-PAI-3S' class="G1510" onclick="luW(7,'127376','24879','1510','V-PAI-3S')" onmouseover="hl1('127376','24879','1510')" onmouseout="hl0('127376','24879','1510')" ondblclick="searchWord(2,127376)">ἐστιν</grk><br><gloss>is</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w18-w22</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w18-w19</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w18</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127377" cl='c24879' sn='G3588' morph='T-NSM' class="G3588" onclick="luW(7,'127377','24879','3588','T-NSM')" onmouseover="hl1('127377','24879','3588')" onmouseout="hl0('127377','24879','3588')" ondblclick="searchWord(2,127377)">ὁ</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w19</wordid><br><funcinfo>head</funcinfo><br><grk id="w127378" cl='c24879' sn='G4108' morph='A-NSM' class="G4108" onclick="luW(7,'127378','24879','4108','A-NSM')" onmouseover="hl1('127378','24879','4108')" onmouseout="hl0('127378','24879','4108')" ondblclick="searchWord(2,127378)">πλάνος</grk><br><gloss>deceiver</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:7.w20-w22</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w20</wordid><br><funcinfo>connector</funcinfo><br><grk id="w127379" cl='c24879' sn='G2532' morph='CONJ' class="G2532" onclick="luW(7,'127379','24879','2532','CONJ')" onmouseover="hl1('127379','24879','2532')" onmouseout="hl0('127379','24879','2532')" ondblclick="searchWord(2,127379)">καὶ</grk><br><gloss>and</gloss></div></w> <w><div class='w'><wordid>w21</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127380" cl='c24879' sn='G3588' morph='T-NSM' class="G3588" onclick="luW(7,'127380','24879','3588','T-NSM')" onmouseover="hl1('127380','24879','3588')" onmouseout="hl0('127380','24879','3588')" ondblclick="searchWord(2,127380)">ὁ</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w22</wordid><br><funcinfo>head</funcinfo><br><grk id="w127381" cl='c24879' sn='G500' morph='N-NSM' class="G500" onclick="luW(7,'127381','24879','500','N-NSM')" onmouseover="hl1('127381','24879','500')" onmouseout="hl0('127381','24879','500')" ondblclick="searchWord(2,127381)">ἀντίχριστος</grk><br><gloss>antichrist.</gloss></div></w></div></div></wg></div></wg></div></cl></verse> <verse><vid id="v63.1.8" onclick="luV(8)">8</vid> <cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:8.w1-w2</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:8.w1</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>head</funcinfo><br><grk id="w127382" cl='c24880' sn='G991' morph='V-PAM-2P' class="G991" onclick="luW(8,'127382','24880','991','V-PAM-2P')" onmouseover="hl1('127382','24880','991')" onmouseout="hl0('127382','24880','991')" ondblclick="searchWord(2,127382)">βλέπετε</grk><br><gloss>Watch</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:8.w2</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w2</wordid><br><funcinfo>head</funcinfo><br><grk id="w127383" cl='c24880' sn='G1438' morph='F-2APM' class="G1438" onclick="luW(8,'127383','24880','1438','F-2APM')" onmouseover="hl1('127383','24880','1438')" onmouseout="hl0('127383','24880','1438')" ondblclick="searchWord(2,127383)">ἑαυτούς</grk><br><gloss>yourselves,</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:8.w3-w7</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:8.w1-w2</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:8.w3</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127384" cl='c24881' sn='G2443' morph='CONJ' class="G2443" onclick="luW(8,'127384','24881','2443','CONJ')" onmouseover="hl1('127384','24881','2443')" onmouseout="hl0('127384','24881','2443')" ondblclick="searchWord(2,127384)">ἵνα</grk><br><gloss>so that</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:8.w4</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>head</funcinfo><br><grk id="w127385" cl='c24881' sn='G3361' morph='PRT-N' class="G3361" onclick="luW(8,'127385','24881','3361','PRT-N')" onmouseover="hl1('127385','24881','3361')" onmouseout="hl0('127385','24881','3361')" ondblclick="searchWord(2,127385)">μὴ</grk><br><gloss>not</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:8.w5</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w5</wordid><br><funcinfo>head</funcinfo><br><grk id="w127386" cl='c24881' sn='G622' morph='V-AAS-2P' class="G622" onclick="luW(8,'127386','24881','622','V-AAS-2P')" onmouseover="hl1('127386','24881','622')" onmouseout="hl0('127386','24881','622')" ondblclick="searchWord(2,127386)">ἀπολέσητε</grk><br><gloss>you should lose</gloss></div></w></div></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>complement</funcinfo> <b><clinfo>1:8.w6-w7</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:8.w6</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w6</wordid><br><funcinfo>head</funcinfo><br><grk id="w127387" cl='c24881' sn='G3739' morph='R-APN' class="G3739" onclick="luW(8,'127387','24881','3739','R-APN')" onmouseover="hl1('127387','24881','3739')" onmouseout="hl0('127387','24881','3739')" ondblclick="searchWord(2,127387)">ἃ</grk><br><gloss>what things</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:8.w7</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w7</wordid><br><funcinfo>head</funcinfo><br><grk id="w127388" cl='c24881' sn='G2038' morph='V-ADI-1P' class="G2038" onclick="luW(8,'127388','24881','2038','V-ADI-1P')" onmouseover="hl1('127388','24881','2038')" onmouseout="hl0('127388','24881','2038')" ondblclick="searchWord(2,127388)">εἰργασάμεθα</grk><br><gloss>we have worked for,</gloss></div></w></div></div></wg></div></cl></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:8.w8-w11</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:8.w3-w7</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:8.w8</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w8</wordid><br><funcinfo>head</funcinfo><br><grk id="w127389" cl='c24882' sn='G235' morph='CONJ' class="G235" onclick="luW(8,'127389','24882','235','CONJ')" onmouseover="hl1('127389','24882','235')" onmouseout="hl0('127389','24882','235')" ondblclick="searchWord(2,127389)">ἀλλὰ</grk><br><gloss>but</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:8.w9-w10</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w9</wordid><br><funcinfo>head</funcinfo><br><grk id="w127390" cl='c24882' sn='G3408' morph='N-ASM' class="G3408" onclick="luW(8,'127390','24882','3408','N-ASM')" onmouseover="hl1('127390','24882','3408')" onmouseout="hl0('127390','24882','3408')" ondblclick="searchWord(2,127390)">μισθὸν</grk><br><gloss>a reward</gloss></div></w> <w><div class='w'><wordid>w10</wordid><br><funcinfo>definer</funcinfo><br><grk id="w127391" cl='c24882' sn='G4134' morph='A-ASM' class="G4134" onclick="luW(8,'127391','24882','4134','A-ASM')" onmouseover="hl1('127391','24882','4134')" onmouseout="hl0('127391','24882','4134')" ondblclick="searchWord(2,127391)">πλήρη</grk><br><gloss>full</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:8.w11</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w11</wordid><br><funcinfo>head</funcinfo><br><grk id="w127392" cl='c24882' sn='G618' morph='V-2AAS-2P' class="G618" onclick="luW(8,'127392','24882','618','V-2AAS-2P')" onmouseover="hl1('127392','24882','618')" onmouseout="hl0('127392','24882','618')" ondblclick="searchWord(2,127392)">ἀπολάβητε</grk><br><gloss>you may receive.</gloss></div></w></div></div></wg></div></cl></verse> <verse><vid id="v63.1.9" onclick="luV(9)">9</vid> <cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:9.w1-w14</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:9.w1-w11</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:9.w1-w3_2</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:9.w1-w3</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>definer</funcinfo><br><grk id="w127393" cl='c24883' sn='G3956' morph='A-NSM' class="G3956" onclick="luW(9,'127393','24883','3956','A-NSM')" onmouseover="hl1('127393','24883','3956')" onmouseout="hl0('127393','24883','3956')" ondblclick="searchWord(2,127393)">πᾶς</grk><br><gloss>Anyone</gloss></div></w> <w><div class='w'><wordid>w2</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127394" cl='c24883' sn='G3588' morph='T-NSM' class="G3588" onclick="luW(9,'127394','24883','3588','T-NSM')" onmouseover="hl1('127394','24883','3588')" onmouseout="hl0('127394','24883','3588')" ondblclick="searchWord(2,127394)">ὁ</grk><br><gloss>-</gloss></div></w> <w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127395" cl='c24883' sn='G4254' morph='V-PAP-NSM' class="G4254" onclick="luW(9,'127395','24883','4254','V-PAP-NSM')" onmouseover="hl1('127395','24883','4254')" onmouseout="hl0('127395','24883','4254')" ondblclick="searchWord(2,127395)">προάγων</grk><br><gloss>going on ahead</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:9.w4-w11</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:9.w4</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>head</funcinfo><br><grk id="w127396" cl='c24884' sn='G2532' morph='CONJ' class="G2532" onclick="luW(9,'127396','24884','2532','CONJ')" onmouseover="hl1('127396','24884','2532')" onmouseout="hl0('127396','24884','2532')" ondblclick="searchWord(2,127396)">καὶ</grk><br><gloss>and</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w5</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w5</wordid><br><funcinfo>head</funcinfo><br><grk id="w127397" cl='c24884' sn='G3361' morph='PRT-N' class="G3361" onclick="luW(9,'127397','24884','3361','PRT-N')" onmouseover="hl1('127397','24884','3361')" onmouseout="hl0('127397','24884','3361')" ondblclick="searchWord(2,127397)">μὴ</grk><br><gloss>not</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w6</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w6</wordid><br><funcinfo>head</funcinfo><br><grk id="w127398" cl='c24884' sn='G3306' morph='V-PAP-NSM' class="G3306" onclick="luW(9,'127398','24884','3306','V-PAP-NSM')" onmouseover="hl1('127398','24884','3306')" onmouseout="hl0('127398','24884','3306')" ondblclick="searchWord(2,127398)">μένων</grk><br><gloss>abiding</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w7-w11</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w7</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127399" cl='c24884' sn='G1722' morph='PREP' class="G1722" onclick="luW(9,'127399','24884','1722','PREP')" onmouseover="hl1('127399','24884','1722')" onmouseout="hl0('127399','24884','1722')" ondblclick="searchWord(2,127399)">ἐν</grk><br><gloss>in</gloss></div></w> <w><div class='w'><wordid>w8</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127400" cl='c24884' sn='G3588' morph='T-DSF' class="G3588" onclick="luW(9,'127400','24884','3588','T-DSF')" onmouseover="hl1('127400','24884','3588')" onmouseout="hl0('127400','24884','3588')" ondblclick="searchWord(2,127400)">τῇ</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w9</wordid><br><funcinfo>head</funcinfo><br><grk id="w127401" cl='c24884' sn='G1322' morph='N-DSF' class="G1322" onclick="luW(9,'127401','24884','1322','N-DSF')" onmouseover="hl1('127401','24884','1322')" onmouseout="hl0('127401','24884','1322')" ondblclick="searchWord(2,127401)">διδαχῇ</grk><br><gloss>teaching</gloss></div></w></div> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w10-w11</subclinfo></b><br><funcinfo>qualifier</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w10</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127402" cl='c24884' sn='G3588' morph='T-GSM' class="G3588" onclick="luW(9,'127402','24884','3588','T-GSM')" onmouseover="hl1('127402','24884','3588')" onmouseout="hl0('127402','24884','3588')" ondblclick="searchWord(2,127402)">τοῦ</grk><br><gloss>-</gloss></div></w> <w><div class='w'><wordid>w11</wordid><br><funcinfo>head</funcinfo><br><grk id="w127403" cl='c24884' sn='G5547' morph='N-GSM-T' class="G5547" onclick="luW(9,'127403','24884','5547','N-GSM-T')" onmouseover="hl1('127403','24884','5547')" onmouseout="hl0('127403','24884','5547')" ondblclick="searchWord(2,127403)">Χριστοῦ</grk><br><gloss>of Christ,</gloss></div></w></div></div></wg></div></wg></div></cl></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w12</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w12</wordid><br><funcinfo>head</funcinfo><br><grk id="w127404" cl='c24884' sn='G2316' morph='N-ASM' class="G2316" onclick="luW(9,'127404','24884','2316','N-ASM')" onmouseover="hl1('127404','24884','2316')" onmouseout="hl0('127404','24884','2316')" ondblclick="searchWord(2,127404)">Θεὸν</grk><br><gloss>God</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w13</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w13</wordid><br><funcinfo>head</funcinfo><br><grk id="w127405" cl='c24884' sn='G3756' morph='PRT-N' class="G3756" onclick="luW(9,'127405','24884','3756','PRT-N')" onmouseover="hl1('127405','24884','3756')" onmouseout="hl0('127405','24884','3756')" ondblclick="searchWord(2,127405)">οὐκ</grk><br><gloss>not</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w14</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w14</wordid><br><funcinfo>head</funcinfo><br><grk id="w127406" cl='c24884' sn='G2192' morph='V-PAI-3S' class="G2192" onclick="luW(9,'127406','24884','2192','V-PAI-3S')" onmouseover="hl1('127406','24884','2192')" onmouseout="hl0('127406','24884','2192')" ondblclick="searchWord(2,127406)">ἔχει</grk><br><gloss>has.</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:9.w15-w19_2</clinfo></b></sup><br><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>subject</funcinfo> <b><clinfo>1:9.w15-w19</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:9.w15-w16</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w15</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127407" cl='c24885' sn='G3588' morph='T-NSM' class="G3588" onclick="luW(9,'127407','24885','3588','T-NSM')" onmouseover="hl1('127407','24885','3588')" onmouseout="hl0('127407','24885','3588')" ondblclick="searchWord(2,127407)">ὁ</grk><br><gloss>The [one]</gloss></div></w> <w><div class='w'><wordid>w16</wordid><br><funcinfo>head</funcinfo><br><grk id="w127408" cl='c24885' sn='G3306' morph='V-PAP-NSM' class="G3306" onclick="luW(9,'127408','24885','3306','V-PAP-NSM')" onmouseover="hl1('127408','24885','3306')" onmouseout="hl0('127408','24885','3306')" ondblclick="searchWord(2,127408)">μένων</grk><br><gloss>abiding</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w17-w19</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w17</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127409" cl='c24885' sn='G1722' morph='PREP' class="G1722" onclick="luW(9,'127409','24885','1722','PREP')" onmouseover="hl1('127409','24885','1722')" onmouseout="hl0('127409','24885','1722')" ondblclick="searchWord(2,127409)">ἐν</grk><br><gloss>in</gloss></div></w> <w><div class='w'><wordid>w18</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127410" cl='c24885' sn='G3588' morph='T-DSF' class="G3588" onclick="luW(9,'127410','24885','3588','T-DSF')" onmouseover="hl1('127410','24885','3588')" onmouseout="hl0('127410','24885','3588')" ondblclick="searchWord(2,127410)">τῇ</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w19</wordid><br><funcinfo>head</funcinfo><br><grk id="w127411" cl='c24885' sn='G1322' morph='N-DSF' class="G1322" onclick="luW(9,'127411','24885','1322','N-DSF')" onmouseover="hl1('127411','24885','1322')" onmouseout="hl0('127411','24885','1322')" ondblclick="searchWord(2,127411)">διδαχῇ</grk><br><gloss>teaching,</gloss></div></w></div></div></wg></div></cl></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:9.w20-w27</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:9.w20</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w20</wordid><br><funcinfo>head</funcinfo><br><grk id="w127412" cl='c24886' sn='G3778' morph='D-NSM' class="G3778" onclick="luW(9,'127412','24886','3778','D-NSM')" onmouseover="hl1('127412','24886','3778')" onmouseout="hl0('127412','24886','3778')" ondblclick="searchWord(2,127412)">οὗτος</grk><br><gloss>this [one]</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w21-w26</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w21-w23</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w21</wordid><br><funcinfo>connector</funcinfo><br><grk id="w127413" cl='c24886' sn='G2532' morph='CONJ' class="G2532" onclick="luW(9,'127413','24886','2532','CONJ')" onmouseover="hl1('127413','24886','2532')" onmouseout="hl0('127413','24886','2532')" ondblclick="searchWord(2,127413)">καὶ</grk><br><gloss>both</gloss></div></w> <w><div class='w'><wordid>w22</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127414" cl='c24886' sn='G3588' morph='T-ASM' class="G3588" onclick="luW(9,'127414','24886','3588','T-ASM')" onmouseover="hl1('127414','24886','3588')" onmouseout="hl0('127414','24886','3588')" ondblclick="searchWord(2,127414)">τὸν</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w23</wordid><br><funcinfo>head</funcinfo><br><grk id="w127415" cl='c24886' sn='G3962' morph='N-ASM' class="G3962" onclick="luW(9,'127415','24886','3962','N-ASM')" onmouseover="hl1('127415','24886','3962')" onmouseout="hl0('127415','24886','3962')" ondblclick="searchWord(2,127415)">Πατέρα</grk><br><gloss>Father</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w24-w26</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w24</wordid><br><funcinfo>connector</funcinfo><br><grk id="w127416" cl='c24886' sn='G2532' morph='CONJ' class="G2532" onclick="luW(9,'127416','24886','2532','CONJ')" onmouseover="hl1('127416','24886','2532')" onmouseout="hl0('127416','24886','2532')" ondblclick="searchWord(2,127416)">καὶ</grk><br><gloss>and</gloss></div></w> <w><div class='w'><wordid>w25</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127417" cl='c24886' sn='G3588' morph='T-ASM' class="G3588" onclick="luW(9,'127417','24886','3588','T-ASM')" onmouseover="hl1('127417','24886','3588')" onmouseout="hl0('127417','24886','3588')" ondblclick="searchWord(2,127417)">τὸν</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w26</wordid><br><funcinfo>head</funcinfo><br><grk id="w127418" cl='c24886' sn='G5207' morph='N-ASM' class="G5207" onclick="luW(9,'127418','24886','5207','N-ASM')" onmouseover="hl1('127418','24886','5207')" onmouseout="hl0('127418','24886','5207')" ondblclick="searchWord(2,127418)">Υἱὸν</grk><br><gloss>Son</gloss></div></w></div></div></wg></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:9.w27</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w27</wordid><br><funcinfo>head</funcinfo><br><grk id="w127419" cl='c24886' sn='G2192' morph='V-PAI-3S' class="G2192" onclick="luW(9,'127419','24886','2192','V-PAI-3S')" onmouseover="hl1('127419','24886','2192')" onmouseout="hl0('127419','24886','2192')" ondblclick="searchWord(2,127419)">ἔχει</grk><br><gloss>has.</gloss></div></w></div></div></wg></div></cl></verse> <verse><vid id="v63.1.10" onclick="luV(10)">10</vid> <cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:10.w1-w5</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:10.w12-w16</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:10.w1</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>head</funcinfo><br><grk id="w127420" cl='c24887' sn='G1487' morph='CONJ' class="G1487" onclick="luW(10,'127420','24887','1487','CONJ')" onmouseover="hl1('127420','24887','1487')" onmouseout="hl0('127420','24887','1487')" ondblclick="searchWord(2,127420)">Εἴ</grk><br><gloss>If</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w2</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w2</wordid><br><funcinfo>head</funcinfo><br><grk id="w127421" cl='c24887' sn='G5100' morph='X-NSM' class="G5100" onclick="luW(10,'127421','24887','5100','X-NSM')" onmouseover="hl1('127421','24887','5100')" onmouseout="hl0('127421','24887','5100')" ondblclick="searchWord(2,127421)">τις</grk><br><gloss>anyone</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w3</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127422" cl='c24887' sn='G2064' morph='V-PNI-3S' class="G2064" onclick="luW(10,'127422','24887','2064','V-PNI-3S')" onmouseover="hl1('127422','24887','2064')" onmouseout="hl0('127422','24887','2064')" ondblclick="searchWord(2,127422)">ἔρχεται</grk><br><gloss>comes</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w4-w5</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127423" cl='c24887' sn='G4314' morph='PREP' class="G4314" onclick="luW(10,'127423','24887','4314','PREP')" onmouseover="hl1('127423','24887','4314')" onmouseout="hl0('127423','24887','4314')" ondblclick="searchWord(2,127423)">πρὸς</grk><br><gloss>to</gloss></div></w> <w><div class='w'><wordid>w5</wordid><br><funcinfo>head</funcinfo><br><grk id="w127424" cl='c24887' sn='G4771' morph='P-2AP' class="G4771" onclick="luW(10,'127424','24887','4771','P-2AP')" onmouseover="hl1('127424','24887','4771')" onmouseout="hl0('127424','24887','4771')" ondblclick="searchWord(2,127424)">ὑμᾶς</grk><br><gloss>you</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:10.w6-w11</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:10.w1-w5</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:10.w6</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w6</wordid><br><funcinfo>head</funcinfo><br><grk id="w127425" cl='c24888' sn='G2532' morph='CONJ' class="G2532" onclick="luW(10,'127425','24888','2532','CONJ')" onmouseover="hl1('127425','24888','2532')" onmouseout="hl0('127425','24888','2532')" ondblclick="searchWord(2,127425)">καὶ</grk><br><gloss>and</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w7-w9</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w7</wordid><br><funcinfo>definer</funcinfo><br><grk id="w127426" cl='c24888' sn='G3778' morph='D-ASF' class="G3778" onclick="luW(10,'127426','24888','3778','D-ASF')" onmouseover="hl1('127426','24888','3778')" onmouseout="hl0('127426','24888','3778')" ondblclick="searchWord(2,127426)">ταύτην</grk><br><gloss>this</gloss></div></w> <w><div class='w'><wordid>w8</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127427" cl='c24888' sn='G3588' morph='T-ASF' class="G3588" onclick="luW(10,'127427','24888','3588','T-ASF')" onmouseover="hl1('127427','24888','3588')" onmouseout="hl0('127427','24888','3588')" ondblclick="searchWord(2,127427)">τὴν</grk><br><gloss>-</gloss></div></w> <w><div class='w'><wordid>w9</wordid><br><funcinfo>head</funcinfo><br><grk id="w127428" cl='c24888' sn='G1322' morph='N-ASF' class="G1322" onclick="luW(10,'127428','24888','1322','N-ASF')" onmouseover="hl1('127428','24888','1322')" onmouseout="hl0('127428','24888','1322')" ondblclick="searchWord(2,127428)">διδαχὴν</grk><br><gloss>teaching</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w10</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w10</wordid><br><funcinfo>head</funcinfo><br><grk id="w127429" cl='c24888' sn='G3756' morph='PRT-N' class="G3756" onclick="luW(10,'127429','24888','3756','PRT-N')" onmouseover="hl1('127429','24888','3756')" onmouseout="hl0('127429','24888','3756')" ondblclick="searchWord(2,127429)">οὐ</grk><br><gloss>not</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w11</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w11</wordid><br><funcinfo>head</funcinfo><br><grk id="w127430" cl='c24888' sn='G5342' morph='V-PAI-3S' class="G5342" onclick="luW(10,'127430','24888','5342','V-PAI-3S')" onmouseover="hl1('127430','24888','5342')" onmouseout="hl0('127430','24888','5342')" ondblclick="searchWord(2,127430)">φέρει</grk><br><gloss>does bring,</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:10.w12-w16</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:10.w12</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w12</wordid><br><funcinfo>head</funcinfo><br><grk id="w127431" cl='c24889' sn='G3361' morph='PRT-N' class="G3361" onclick="luW(10,'127431','24889','3361','PRT-N')" onmouseover="hl1('127431','24889','3361')" onmouseout="hl0('127431','24889','3361')" ondblclick="searchWord(2,127431)">μὴ</grk><br><gloss>not</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w13</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w13</wordid><br><funcinfo>head</funcinfo><br><grk id="w127432" cl='c24889' sn='G2983' morph='V-PAM-2P' class="G2983" onclick="luW(10,'127432','24889','2983','V-PAM-2P')" onmouseover="hl1('127432','24889','2983')" onmouseout="hl0('127432','24889','2983')" ondblclick="searchWord(2,127432)">λαμβάνετε</grk><br><gloss>receive</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w14</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w14</wordid><br><funcinfo>head</funcinfo><br><grk id="w127433" cl='c24889' sn='G846' morph='P-ASM' class="G846" onclick="luW(10,'127433','24889','846','P-ASM')" onmouseover="hl1('127433','24889','846')" onmouseout="hl0('127433','24889','846')" ondblclick="searchWord(2,127433)">αὐτὸν</grk><br><gloss>him</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w15-w16</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w15</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127434" cl='c24889' sn='G1519' morph='PREP' class="G1519" onclick="luW(10,'127434','24889','1519','PREP')" onmouseover="hl1('127434','24889','1519')" onmouseout="hl0('127434','24889','1519')" ondblclick="searchWord(2,127434)">εἰς</grk><br><gloss>into</gloss></div></w> <w><div class='w'><wordid>w16</wordid><br><funcinfo>head</funcinfo><br><grk id="w127435" cl='c24889' sn='G3614' morph='N-ASF' class="G3614" onclick="luW(10,'127435','24889','3614','N-ASF')" onmouseover="hl1('127435','24889','3614')" onmouseout="hl0('127435','24889','3614')" ondblclick="searchWord(2,127435)">οἰκίαν</grk><br><gloss>[the] house,</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:10.w17-w21</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:10.w17</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w17</wordid><br><funcinfo>head</funcinfo><br><grk id="w127436" cl='c24890' sn='G2532' morph='CONJ' class="G2532" onclick="luW(10,'127436','24890','2532','CONJ')" onmouseover="hl1('127436','24890','2532')" onmouseout="hl0('127436','24890','2532')" ondblclick="searchWord(2,127436)">καὶ</grk><br><gloss>and</gloss></div></w></div></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>complement</funcinfo> <b><clinfo>1:10.w18_2</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:10.w18</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w18</wordid><br><funcinfo>head</funcinfo><br><grk id="w127437" cl='c24890' sn='G5463' morph='V-PAN' class="G5463" onclick="luW(10,'127437','24890','5463','V-PAN')" onmouseover="hl1('127437','24890','5463')" onmouseout="hl0('127437','24890','5463')" ondblclick="searchWord(2,127437)">χαίρειν</grk><br><gloss>to rejoice</gloss></div></w></div></div></wg></div></cl><wg><div class='p'><wg><div class='p'><subclinfo>1:10.w19</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w19</wordid><br><funcinfo>head</funcinfo><br><grk id="w127438" cl='c24890' sn='G846' morph='P-DSM' class="G846" onclick="luW(10,'127438','24890','846','P-DSM')" onmouseover="hl1('127438','24890','846')" onmouseout="hl0('127438','24890','846')" ondblclick="searchWord(2,127438)">αὐτῷ</grk><br><gloss>him</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w20</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w20</wordid><br><funcinfo>head</funcinfo><br><grk id="w127439" cl='c24890' sn='G3361' morph='PRT-N' class="G3361" onclick="luW(10,'127439','24890','3361','PRT-N')" onmouseover="hl1('127439','24890','3361')" onmouseout="hl0('127439','24890','3361')" ondblclick="searchWord(2,127439)">μὴ</grk><br><gloss>not</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:10.w21</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w21</wordid><br><funcinfo>head</funcinfo><br><grk id="w127440" cl='c24890' sn='G3004' morph='V-PAM-2P' class="G3004" onclick="luW(10,'127440','24890','3004','V-PAM-2P')" onmouseover="hl1('127440','24890','3004')" onmouseout="hl0('127440','24890','3004')" ondblclick="searchWord(2,127440)">λέγετε</grk><br><gloss>tell;</gloss></div></w></div></div></wg></div></cl></verse> <verse><vid id="v63.1.11" onclick="luV(11)">11</vid> <cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:11.w1-w11</clinfo></b></sup><br><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>subject</funcinfo> <b><clinfo>1:11.w1-w2_2</clinfo></b><br><funcinfo>→</funcinfo> <i><clinfo>1:11.w4-w5</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:11.w1-w2</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127441" cl='c24891' sn='G3588' morph='T-NSM' class="G3588" onclick="luW(11,'127441','24891','3588','T-NSM')" onmouseover="hl1('127441','24891','3588')" onmouseout="hl0('127441','24891','3588')" ondblclick="searchWord(2,127441)">ὁ</grk><br><gloss>the [one]</gloss></div></w> <w><div class='w'><wordid>w2</wordid><br><funcinfo>head</funcinfo><br><grk id="w127442" cl='c24891' sn='G3004' morph='V-PAP-NSM' class="G3004" onclick="luW(11,'127442','24891','3004','V-PAP-NSM')" onmouseover="hl1('127442','24891','3004')" onmouseout="hl0('127442','24891','3004')" ondblclick="searchWord(2,127442)">λέγων</grk><br><gloss>telling</gloss></div></w></div></div></wg></div></cl><wg><div class='p'><wg><div class='p'><subclinfo>1:11.w3</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127443" cl='c24891' sn='G1063' morph='CONJ' class="G1063" onclick="luW(11,'127443','24891','1063','CONJ')" onmouseover="hl1('127443','24891','1063')" onmouseout="hl0('127443','24891','1063')" ondblclick="searchWord(2,127443)">γὰρ</grk><br><gloss>for</gloss></div></w></div></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:11.w4-w5</clinfo></b> <br><i><clinfo>1:11.w1-w2_2</clinfo></i> <funcinfo>←</funcinfo></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:11.w4</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>head</funcinfo><br><grk id="w127444" cl='c24891' sn='G846' morph='P-DSM' class="G846" onclick="luW(11,'127444','24891','846','P-DSM')" onmouseover="hl1('127444','24891','846')" onmouseout="hl0('127444','24891','846')" ondblclick="searchWord(2,127444)">αὐτῷ</grk><br><gloss>him</gloss></div></w></div></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>complement</funcinfo> <b><clinfo>1:11.w5_2</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:11.w5</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w5</wordid><br><funcinfo>head</funcinfo><br><grk id="w127445" cl='c24891' sn='G5463' morph='V-PAN' class="G5463" onclick="luW(11,'127445','24891','5463','V-PAN')" onmouseover="hl1('127445','24891','5463')" onmouseout="hl0('127445','24891','5463')" ondblclick="searchWord(2,127445)">χαίρειν</grk><br><gloss>to rejoice</gloss></div></w></div></div></wg></div></cl></div></cl><wg><div class='p'><wg><div class='p'><subclinfo>1:11.w6</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w6</wordid><br><funcinfo>head</funcinfo><br><grk id="w127446" cl='c24892' sn='G2841' morph='V-PAI-3S' class="G2841" onclick="luW(11,'127446','24892','2841','V-PAI-3S')" onmouseover="hl1('127446','24892','2841')" onmouseout="hl0('127446','24892','2841')" ondblclick="searchWord(2,127446)">κοινωνεῖ</grk><br><gloss>partakes</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:11.w7-w11</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w7</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127447" cl='c24892' sn='G3588' morph='T-DPN' class="G3588" onclick="luW(11,'127447','24892','3588','T-DPN')" onmouseover="hl1('127447','24892','3588')" onmouseout="hl0('127447','24892','3588')" ondblclick="searchWord(2,127447)">τοῖς</grk><br><gloss>in the</gloss></div></w> <w><div class='w'><wordid>w8</wordid><br><funcinfo>head</funcinfo><br><grk id="w127448" cl='c24892' sn='G2041' morph='N-DPN' class="G2041" onclick="luW(11,'127448','24892','2041','N-DPN')" onmouseover="hl1('127448','24892','2041')" onmouseout="hl0('127448','24892','2041')" ondblclick="searchWord(2,127448)">ἔργοις</grk><br><gloss>works</gloss></div></w> <w><div class='w'><wordid>w9</wordid><br><funcinfo>qualifier</funcinfo><br><grk id="w127449" cl='c24892' sn='G846' morph='P-GSM' class="G846" onclick="luW(11,'127449','24892','846','P-GSM')" onmouseover="hl1('127449','24892','846')" onmouseout="hl0('127449','24892','846')" ondblclick="searchWord(2,127449)">αὐτοῦ</grk><br><gloss>of him</gloss></div></w></div> <wg><div class='p'><wg><div class='p'><subclinfo>1:11.w10-w11</subclinfo></b><br><funcinfo>definer</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w10</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127450" cl='c24892' sn='G3588' morph='T-DPN' class="G3588" onclick="luW(11,'127450','24892','3588','T-DPN')" onmouseover="hl1('127450','24892','3588')" onmouseout="hl0('127450','24892','3588')" ondblclick="searchWord(2,127450)">τοῖς</grk><br><gloss>-</gloss></div></w> <w><div class='w'><wordid>w11</wordid><br><funcinfo>head</funcinfo><br><grk id="w127451" cl='c24892' sn='G4190' morph='A-DPN' class="G4190" onclick="luW(11,'127451','24892','4190','A-DPN')" onmouseover="hl1('127451','24892','4190')" onmouseout="hl0('127451','24892','4190')" ondblclick="searchWord(2,127451)">πονηροῖς</grk><br><gloss>evil.</gloss></div></w></div></div></wg></div></wg></div></cl></verse> <verse><vid id="v63.1.12" onclick="luV(12)">12</vid> <cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:12.w1-w10</clinfo></b></sup><br><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>adjunct</funcinfo> <b><clinfo>1:12.w1-w4</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:12.w1</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>head</funcinfo><br><grk id="w127452" cl='c24893' sn='G4183' morph='A-APN' class="G4183" onclick="luW(12,'127452','24893','4183','A-APN')" onmouseover="hl1('127452','24893','4183')" onmouseout="hl0('127452','24893','4183')" ondblclick="searchWord(2,127452)">Πολλὰ</grk><br><gloss>Many things</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w2</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w2</wordid><br><funcinfo>head</funcinfo><br><grk id="w127453" cl='c24893' sn='G2192' morph='V-PAP-NSM' class="G2192" onclick="luW(12,'127453','24893','2192','V-PAP-NSM')" onmouseover="hl1('127453','24893','2192')" onmouseout="hl0('127453','24893','2192')" ondblclick="searchWord(2,127453)">ἔχων</grk><br><gloss>having</gloss></div></w></div></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>complement</funcinfo> <b><clinfo>1:12.w3-w4</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:12.w3</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w3</wordid><br><funcinfo>head</funcinfo><br><grk id="w127454" cl='c24894' sn='G4771' morph='P-2DP' class="G4771" onclick="luW(12,'127454','24894','4771','P-2DP')" onmouseover="hl1('127454','24894','4771')" onmouseout="hl0('127454','24894','4771')" ondblclick="searchWord(2,127454)">ὑμῖν</grk><br><gloss>to you</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w4</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w4</wordid><br><funcinfo>head</funcinfo><br><grk id="w127455" cl='c24894' sn='G1125' morph='V-PAN' class="G1125" onclick="luW(12,'127455','24894','1125','V-PAN')" onmouseover="hl1('127455','24894','1125')" onmouseout="hl0('127455','24894','1125')" ondblclick="searchWord(2,127455)">γράφειν</grk><br><gloss>to write,</gloss></div></w></div></div></wg></div></cl></div></cl><wg><div class='p'><wg><div class='p'><subclinfo>1:12.w5</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w5</wordid><br><funcinfo>head</funcinfo><br><grk id="w127456" cl='c24895' sn='G3756' morph='PRT-N' class="G3756" onclick="luW(12,'127456','24895','3756','PRT-N')" onmouseover="hl1('127456','24895','3756')" onmouseout="hl0('127456','24895','3756')" ondblclick="searchWord(2,127456)">οὐκ</grk><br><gloss>not</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w6</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w6</wordid><br><funcinfo>head</funcinfo><br><grk id="w127457" cl='c24895' sn='G1014' morph='V-AOI-1S' class="G1014" onclick="luW(12,'127457','24895','1014','V-AOI-1S')" onmouseover="hl1('127457','24895','1014')" onmouseout="hl0('127457','24895','1014')" ondblclick="searchWord(2,127457)">ἐβουλήθην</grk><br><gloss>I purposed</gloss></div></w></div></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>complement</funcinfo> <b><clinfo>1:12.w7-w10_2</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:12.w7-w10</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w7-w8</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w7</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127458" cl='c24895' sn='G1223' morph='PREP' class="G1223" onclick="luW(12,'127458','24895','1223','PREP')" onmouseover="hl1('127458','24895','1223')" onmouseout="hl0('127458','24895','1223')" ondblclick="searchWord(2,127458)">διὰ</grk><br><gloss>with</gloss></div></w> <w><div class='w'><wordid>w8</wordid><br><funcinfo>head</funcinfo><br><grk id="w127459" cl='c24895' sn='G5489' morph='N-GSM' class="G5489" onclick="luW(12,'127459','24895','5489','N-GSM')" onmouseover="hl1('127459','24895','5489')" onmouseout="hl0('127459','24895','5489')" ondblclick="searchWord(2,127459)">χάρτου</grk><br><gloss>paper</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w9-w10</subclinfo></b></div></wg> <div class='wrap'><w><div class='w'><wordid>w9</wordid><br><funcinfo>connector</funcinfo><br><grk id="w127460" cl='c24895' sn='G2532' morph='CONJ' class="G2532" onclick="luW(12,'127460','24895','2532','CONJ')" onmouseover="hl1('127460','24895','2532')" onmouseout="hl0('127460','24895','2532')" ondblclick="searchWord(2,127460)">καὶ</grk><br><gloss>and</gloss></div></w> <w><div class='w'><wordid>w10</wordid><br><funcinfo>head</funcinfo><br><grk id="w127461" cl='c24895' sn='G3188' morph='N-GSN' class="G3188" onclick="luW(12,'127461','24895','3188','N-GSN')" onmouseover="hl1('127461','24895','3188')" onmouseout="hl0('127461','24895','3188')" ondblclick="searchWord(2,127461)">μέλανος</grk><br><gloss>ink;</gloss></div></w></div></div></wg></div></wg></div></cl></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:12.w11-w20</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:12.w11</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w11</wordid><br><funcinfo>head</funcinfo><br><grk id="w127462" cl='c24896' sn='G235' morph='CONJ' class="G235" onclick="luW(12,'127462','24896','235','CONJ')" onmouseover="hl1('127462','24896','235')" onmouseout="hl0('127462','24896','235')" ondblclick="searchWord(2,127462)">ἀλλὰ</grk><sup><a href="javascript:void(0)" onclick="word('127462')">=</a></sup><br><gloss>but</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w12</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w12</wordid><br><funcinfo>head</funcinfo><br><grk id="w127463" cl='c24896' sn='G1679' morph='V-PAI-1S' class="G1679" onclick="luW(12,'127463','24896','1679','V-PAI-1S')" onmouseover="hl1('127463','24896','1679')" onmouseout="hl0('127463','24896','1679')" ondblclick="searchWord(2,127463)">ἐλπίζω</grk><br><gloss>I hope</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w13-w20</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:12.w13-w15</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:12.w13</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w13</wordid><br><funcinfo>head</funcinfo><br><grk id="w127464" cl='c24896' sn='G1096' morph='V-2ADN' class="G1096" onclick="luW(12,'127464','24896','1096','V-2ADN')" onmouseover="hl1('127464','24896','1096')" onmouseout="hl0('127464','24896','1096')" ondblclick="searchWord(2,127464)">γενέσθαι</grk><br><gloss>to come</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w14-w15</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w14</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127465" cl='c24896' sn='G4314' morph='PREP' class="G4314" onclick="luW(12,'127465','24896','4314','PREP')" onmouseover="hl1('127465','24896','4314')" onmouseout="hl0('127465','24896','4314')" ondblclick="searchWord(2,127465)">πρὸς</grk><br><gloss>to</gloss></div></w> <w><div class='w'><wordid>w15</wordid><br><funcinfo>head</funcinfo><br><grk id="w127466" cl='c24896' sn='G4771' morph='P-2AP' class="G4771" onclick="luW(12,'127466','24896','4771','P-2AP')" onmouseover="hl1('127466','24896','4771')" onmouseout="hl0('127466','24896','4771')" ondblclick="searchWord(2,127466)">ὑμᾶς</grk><br><gloss>you,</gloss></div></w></div></div></wg></div></cl><cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:12.w16-w20</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:12.w16</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w16</wordid><br><funcinfo>head</funcinfo><br><grk id="w127467" cl='c24897' sn='G2532' morph='CONJ' class="G2532" onclick="luW(12,'127467','24897','2532','CONJ')" onmouseover="hl1('127467','24897','2532')" onmouseout="hl0('127467','24897','2532')" ondblclick="searchWord(2,127467)">καὶ</grk><br><gloss>and</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w17-w19</subclinfo></b><br><funcinfo>adjunct</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w17</wordid><br><funcinfo>head</funcinfo><br><grk id="w127468" cl='c24897' sn='G4750' morph='N-ASN' class="G4750" onclick="luW(12,'127468','24897','4750','N-ASN')" onmouseover="hl1('127468','24897','4750')" onmouseout="hl0('127468','24897','4750')" ondblclick="searchWord(2,127468)">στόμα</grk><br><gloss>mouth</gloss></div></w></div> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w18-w19</subclinfo></b><br><funcinfo>relator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w18</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127469" cl='c24897' sn='G4314' morph='PREP' class="G4314" onclick="luW(12,'127469','24897','4314','PREP')" onmouseover="hl1('127469','24897','4314')" onmouseout="hl0('127469','24897','4314')" ondblclick="searchWord(2,127469)">πρὸς</grk><br><gloss>to</gloss></div></w> <w><div class='w'><wordid>w19</wordid><br><funcinfo>head</funcinfo><br><grk id="w127470" cl='c24897' sn='G4750' morph='N-ASN' class="G4750" onclick="luW(12,'127470','24897','4750','N-ASN')" onmouseover="hl1('127470','24897','4750')" onmouseout="hl0('127470','24897','4750')" ondblclick="searchWord(2,127470)">στόμα</grk><br><gloss>mouth</gloss></div></w></div></div></wg></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w20</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w20</wordid><br><funcinfo>head</funcinfo><br><grk id="w127471" cl='c24897' sn='G2980' morph='V-AAN' class="G2980" onclick="luW(12,'127471','24897','2980','V-AAN')" onmouseover="hl1('127471','24897','2980')" onmouseout="hl0('127471','24897','2980')" ondblclick="searchWord(2,127471)">λαλῆσαι</grk><br><gloss>to speak,</gloss></div></w></div></div></wg></div></cl></div></wg></div></cl><cl><div class='c'><sup><cllevel>°°</cllevel> <b><clinfo>1:12.w21-w26</clinfo></b></sup> <sup> <connector>@</connector><i><clinfo>1:12.w11-w20</clinfo></i></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:12.w21</subclinfo></b><br><funcinfo>conjunction</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w21</wordid><br><funcinfo>head</funcinfo><br><grk id="w127472" cl='c24898' sn='G2443' morph='CONJ' class="G2443" onclick="luW(12,'127472','24898','2443','CONJ')" onmouseover="hl1('127472','24898','2443')" onmouseout="hl0('127472','24898','2443')" ondblclick="searchWord(2,127472)">ἵνα</grk><br><gloss>so that</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w22-w24</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w22</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127473" cl='c24898' sn='G3588' morph='T-NSF' class="G3588" onclick="luW(12,'127473','24898','3588','T-NSF')" onmouseover="hl1('127473','24898','3588')" onmouseout="hl0('127473','24898','3588')" ondblclick="searchWord(2,127473)">ἡ</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w23</wordid><br><funcinfo>head</funcinfo><br><grk id="w127474" cl='c24898' sn='G5479' morph='N-NSF' class="G5479" onclick="luW(12,'127474','24898','5479','N-NSF')" onmouseover="hl1('127474','24898','5479')" onmouseout="hl0('127474','24898','5479')" ondblclick="searchWord(2,127474)">χαρὰ</grk><br><gloss>joy</gloss></div></w> <w><div class='w'><wordid>w24</wordid><br><funcinfo>qualifier</funcinfo><br><grk id="w127475" cl='c24898' sn='G1473' morph='P-1GP' class="G1473" onclick="luW(12,'127475','24898','1473','P-1GP')" onmouseover="hl1('127475','24898','1473')" onmouseout="hl0('127475','24898','1473')" ondblclick="searchWord(2,127475)">ἡμῶν</grk><br><gloss>of us</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:12.w25</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w25</wordid><br><funcinfo>head</funcinfo><br><grk id="w127476" cl='c24898' sn='G1510' morph='V-PAS-3S' class="G1510" onclick="luW(12,'127476','24898','1510','V-PAS-3S')" onmouseover="hl1('127476','24898','1510')" onmouseout="hl0('127476','24898','1510')" ondblclick="searchWord(2,127476)">ᾖ</grk><br><gloss>may be.</gloss></div></w></div></div></wg><cl><div class='c'><sup><cllevel>°</cllevel> <funcinfo>complement</funcinfo> <b><clinfo>1:12.w26_2</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:12.w26</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w26</wordid><br><funcinfo>head</funcinfo><br><grk id="w127477" cl='c24898' sn='G4137' morph='V-RPP-NSF' class="G4137" onclick="luW(12,'127477','24898','4137','V-RPP-NSF')" onmouseover="hl1('127477','24898','4137')" onmouseout="hl0('127477','24898','4137')" ondblclick="searchWord(2,127477)">πεπληρωμένη</grk><br><gloss>having been completed</gloss></div></w></div></div></wg></div></cl></div></cl></verse> <verse><vid id="v63.1.13" onclick="luV(13)">13</vid> <cl><div class='c'><sup><cllevel>°</cllevel> <b><clinfo>1:13.w1-w9</clinfo></b></sup><br><wg><div class='p'><wg><div class='p'><subclinfo>1:13.w1</subclinfo></b><br><funcinfo>predicator</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w1</wordid><br><funcinfo>head</funcinfo><br><grk id="w127478" cl='c24899' sn='G782' morph='V-PNI-3S' class="G782" onclick="luW(13,'127478','24899','782','V-PNI-3S')" onmouseover="hl1('127478','24899','782')" onmouseout="hl0('127478','24899','782')" ondblclick="searchWord(2,127478)">Ἀσπάζεταί</grk><br><gloss>Greet</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:13.w2</subclinfo></b><br><funcinfo>complement</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w2</wordid><br><funcinfo>head</funcinfo><br><grk id="w127479" cl='c24899' sn='G4771' morph='P-2AS' class="G4771" onclick="luW(13,'127479','24899','4771','P-2AS')" onmouseover="hl1('127479','24899','4771')" onmouseout="hl0('127479','24899','4771')" ondblclick="searchWord(2,127479)">σε</grk><br><gloss>you,</gloss></div></w></div></div></wg> <wg><div class='p'><wg><div class='p'><subclinfo>1:13.w3-w9</subclinfo></b><br><funcinfo>subject</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w3</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127480" cl='c24899' sn='G3588' morph='T-NPN' class="G3588" onclick="luW(13,'127480','24899','3588','T-NPN')" onmouseover="hl1('127480','24899','3588')" onmouseout="hl0('127480','24899','3588')" ondblclick="searchWord(2,127480)">τὰ</grk><br><gloss>the</gloss></div></w> <w><div class='w'><wordid>w4</wordid><br><funcinfo>head</funcinfo><br><grk id="w127481" cl='c24899' sn='G5043' morph='N-NPN' class="G5043" onclick="luW(13,'127481','24899','5043','N-NPN')" onmouseover="hl1('127481','24899','5043')" onmouseout="hl0('127481','24899','5043')" ondblclick="searchWord(2,127481)">τέκνα</grk><br><gloss>children</gloss></div></w></div> <wg><div class='p'><wg><div class='p'><subclinfo>1:13.w5-w9</subclinfo></b><br><funcinfo>qualifier</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w5</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127482" cl='c24899' sn='G3588' morph='T-GSF' class="G3588" onclick="luW(13,'127482','24899','3588','T-GSF')" onmouseover="hl1('127482','24899','3588')" onmouseout="hl0('127482','24899','3588')" ondblclick="searchWord(2,127482)">τῆς</grk><br><gloss>of the</gloss></div></w> <w><div class='w'><wordid>w6</wordid><br><funcinfo>head</funcinfo><br><grk id="w127483" cl='c24899' sn='G79' morph='N-GSF' class="G79" onclick="luW(13,'127483','24899','79','N-GSF')" onmouseover="hl1('127483','24899','79')" onmouseout="hl0('127483','24899','79')" ondblclick="searchWord(2,127483)">ἀδελφῆς</grk><br><gloss>sister</gloss></div></w> <w><div class='w'><wordid>w7</wordid><br><funcinfo>qualifier</funcinfo><br><grk id="w127484" cl='c24899' sn='G4771' morph='P-2GS' class="G4771" onclick="luW(13,'127484','24899','4771','P-2GS')" onmouseover="hl1('127484','24899','4771')" onmouseout="hl0('127484','24899','4771')" ondblclick="searchWord(2,127484)">σου</grk><br><gloss>of you</gloss></div></w></div> <wg><div class='p'><wg><div class='p'><subclinfo>1:13.w8-w9</subclinfo></b><br><funcinfo>definer</funcinfo></div></wg> <div class='wrap'><w><div class='w'><wordid>w8</wordid><br><funcinfo>specifier</funcinfo><br><grk id="w127485" cl='c24899' sn='G3588' morph='T-GSF' class="G3588" onclick="luW(13,'127485','24899','3588','T-GSF')" onmouseover="hl1('127485','24899','3588')" onmouseout="hl0('127485','24899','3588')" ondblclick="searchWord(2,127485)">τῆς</grk><br><gloss>-</gloss></div></w> <w><div class='w'><wordid>w9</wordid><br><funcinfo>head</funcinfo><br><grk id="w127486" cl='c24899' sn='G1588' morph='A-GSF' class="G1588" onclick="luW(13,'127486','24899','1588','A-GSF')" onmouseover="hl1('127486','24899','1588')" onmouseout="hl0('127486','24899','1588')" ondblclick="searchWord(2,127486)">ἐκλεκτῆς</grk><br><gloss>elect.</gloss></div></w></div></div></wg></div></wg></div></wg></div></cl></verse>"""

    content = greek_content

    # Fix known issues
    content = content.replace("<br<", "<br><")

    # convert verse link, like '<vid id="v19.117.1" onclick="luV(1)">'
    content = re.sub(r'<vid id="v([0-9]+?)\.([0-9]+?)\.([0-9]+?)" onclick="luV\(([0-9]+?)\)">', r'<vid id="v\1.\2.\3" onclick="luV(\1, \2, \3)">', content)
    
    # Convert onclick and ondblclick links
    content = re.sub(r'''(onclick|ondblclick)="(luV|luW|lex|bdbid|etcbcmorph|rmac|searchLexicalEntry|searchWord)\((.*?)\)"''', r'''\1="emitEvent('\2', [\3]); return false;"''', content)
    content = re.sub(r"""(onclick|ondblclick)='(luV|luW|lex|bdbid|etcbcmorph|rmac|searchLexicalEntry|searchWord)\((.*?)\)'""", r"""\1='emitEvent("\2", [\3]); return false;'""", content)

    # Inject CSS to handle the custom tags and layout
    if "</heb>" in content:
        ui.add_head_html("""
        <style>
            /* Main container for the Bible text - ensures RTL flow for verses */
            .bible-text {
                direction: rtl;
                font-family: sans-serif;
                padding: 20px;
                background-color: #fafafa;
            }
            /* Verse ID Number */
            vid {
                color: navy;
                font-weight: bold;
                font-size: 0.9rem;
                margin-left: 10px; /* appears on the right due to RTL */
                cursor: pointer;
            }
            /* Hebrew Word Layer */
            wform, heb, bdbheb, bdbarc, hu {
                font-family: 'SBL Hebrew', 'Ezra SIL', serif;
                font-size: 1.6rem;
                color: #2c3e50;
                direction: rtl;
                display: inline-block;
                line-height: 1.2em;
                margin-top: 0;
                margin-bottom: -2px;
                cursor: pointer;
            }
            /* Lexical Form & Strong's Number Layers */
            wlex {
                display: block;
                font-family: 'SBL Hebrew', serif;
                font-size: 1rem;
                color: #555;
                cursor: pointer;
            }
        </style>
        """)
    else:
        ui.add_head_html("""
        <style>
            /* Main container for the Bible text - LTR flow for Greek */
            .bible-text {
                direction: ltr;
                font-family: sans-serif;
                padding: 20px;
                background-color: #fafafa;
            }
            /* Verse ID Number */
            vid {
                color: navy;
                font-weight: bold;
                font-size: 0.9rem;
                margin-right: 10px;
                cursor: pointer;
            }
            /* Greek Word Layer (targets <grk> tag) */
            wform, grk, kgrk, gu {
                font-family: 'SBL Greek', 'Galatia SIL', 'Times New Roman', serif; /* CHANGED */
                font-size: 1.6rem;
                color: #2c3e50;
                direction: ltr;
                display: inline-block;
                line-height: 1.2em;
                margin-top: 0;
                margin-bottom: -2px;
                cursor: pointer;
            }
            /* Lexical Form (lemma) & Strong's Number Layers */
            wlex {
                display: block;
                font-family: 'SBL Greek', 'Galatia SIL', 'Times New Roman', serif; /* CHANGED */
                font-size: 1rem;
                color: #555;
                cursor: pointer;
            }
        </style>
        """)
    
    ui.add_head_html(ORIGINAL_CSS)

    # Header
    chapter_title = "Psalm 117" if "</heb>" in content else "2 John" # For testing only
    ui.label(f"Original Linguistic Bible (OLB) - {chapter_title}").classes('text-2xl font-bold q-mb-md text-center w-full')

    # Render the HTML inside a styled container
    # REMEMBER: sanitize=False is required to keep your onclick/onmouseover attributes
    ui.html(f'<div class="bible-text">{content}</div>', sanitize=False).classes(f'w-full pb-[60vh] {(tab1+"_chapter") if area == 1 else (tab2+"_chapter")}')

    # After the page is built and ready, run our JavaScript
    if (not area == 1) and tab1 and tab2:
        ui.run_javascript(f"""
            {SYNC_JS}
            
            {get_sync_fx(tab1, tab2)}
        """)

    # scrolling, e.g.
    ui.run_javascript(f'scrollToVerse("v{b}.{c}.{v}")')